@@ -37,6 +37,7 @@
  * exclusive of extension of file system concurrently.
  */
 
+#include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -52,7 +53,6 @@
 #include "jfs_xtree.h"
 #include "jfs_dtree.h"
 #include "jfs_defragfs.h"
-#include "jfs_debug.h"
 
 #include "devices.h"
 #include "debug.h"
@@ -62,17 +62,23 @@
 #include "message.h"
 
 /*
- *	debug control (ref. jfs_debug.h)
+ *	debug control
  */
-#ifdef	_JFS_DEBUG
-int32_t	jfsFYI = 1;	/* global enable FYI message */
-int32_t	jfsALERT = 1;	/* global enable ALERT message */
-int32_t	jfsERROR = 1;	/* global enable ERROR message */
-#else	/* ! _JFS_DEBUG */
-int32_t	jfsFYI = 0;	/* global disable FYI message */
-int32_t	jfsALERT = 0;	/* global disable ALERT message */
-int32_t	jfsERROR = 0;	/* global disable ERROR message */
-#endif	/* _JFS_DEBUG */
+#ifdef _JFS_DEBUG
+/* information message: e.g., configuration, major event */
+#define jFYI(button,prspec) \
+     do { if (button) printk prspec; } while (0)
+/* debug event message: */
+#define jEVENT(button,prspec) \
+     do { if (button) printk prspec; } while (0)
+/* error event message: e.g., i/o error */
+#define jERROR(button,prspec) \
+     do { if (button) printk prspec; } while (0)
+#else                        /* _JFS_DEBUG */
+#define jEVENT(button,prspec)
+#define jFYI(button,prspec)
+#define jERROR(button,prspec)
+#endif                       /* _JFS_DEBUG */
 
 /* command control */
 #define DEFRAG           1
@@ -285,8 +291,7 @@ int main(int argc, char **argv)
 	/* parse command line arguments */
 	if ( (rc = whatDoYouWant(argc, argv)) )
 	{
-		message_user(MSG_JFS_DEFRAGFS_USAGE, NULL, 0, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_DEFRAGFS_USAGE, NULL, 0, JFS_MSG);
 		goto out;
 	}
 
@@ -310,8 +315,7 @@ mainidea:
 	if (DoIt == true)
 	{
 		msg_parms[0] = LVName;
-		message_user(MSG_JFS_DEFRAGMENTING, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_DEFRAGMENTING, msg_parms, 1, JFS_MSG);
 	}
 	/*
 	 * report pre-defragmentation statistics and 
@@ -323,8 +327,7 @@ mainidea:
 	/* report post-defragmentation statistics */
 	if (DoIt == true)
 	{
-		message_user(MSG_JFS_DEFRAGFS_COMPLETE, NULL, 0, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_DEFRAGFS_COMPLETE, NULL, 0, JFS_MSG);
 		DoIt = false;
 		goto mainidea;
 	}
@@ -343,8 +346,8 @@ out:
 static int32_t defragfs(void)
 {
 	int32_t	   rc = 0;
-    dbmap_t	   *gcp;	/* bmap global control page */
-	dmapctl_t  *lcp; /* bmap level control page */
+	dbmap_t	   *gcp;	/* bmap global control page */
+	dmapctl_t  *lcp = NULL;	/* bmap level control page */
 	int32_t	   nBMap;
 	int32_t	   nAG;
 	int32_t	   nFullAG;
@@ -548,8 +551,7 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 #ifdef _JFS_OS2
 	_itoa(nAG, msgstr,10);
 	msg_parms[0] = msgstr;
-	message_user(MSG_JFS_TOTAL_AGS, msg_parms, 1, STDOUT_CODE,
-		     NO_RESPONSE, JFS_MSG);
+	message_user(MSG_JFS_TOTAL_AGS, msg_parms, 1, JFS_MSG);
 #endif
 
 	if (AG_SKIP_FREE)
@@ -558,8 +560,7 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 #ifdef _JFS_OS2
 		_itoa(AG_SKIP_FREE, msgstr,10);
 		msg_parms[0] = msgstr;
-		message_user(MSG_JFS_SKIPPED_FREE, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_SKIPPED_FREE, msg_parms, 1, JFS_MSG);
 #endif 
 	}
 
@@ -568,8 +569,7 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 #ifdef _JFS_OS2 
 		_itoa(AG_SKIP_FULL, msgstr,10);
 		msg_parms[0] = msgstr;
-		message_user(MSG_JFS_SKIPPED_FULL, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_SKIPPED_FULL, msg_parms, 1, JFS_MSG);
 #endif 
 	}
 
@@ -579,8 +579,7 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 #ifdef _JFS_OS2
 		_itoa(AG_SKIP_LONG_RUN, msgstr,10);
 		msg_parms[0] = msgstr;
-		message_user(MSG_JFS_SKIPPED_CONTIG, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_SKIPPED_CONTIG, msg_parms, 1, JFS_MSG);
 #endif 
 	}
 
@@ -589,14 +588,11 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 	msg_parms[0] = msgstr;
 #endif 
 
-	if (DoIt == true)
-		message_user(MSG_JFS_NUM_DEFRAGED, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+	if (DoIt)
+		message_user(MSG_JFS_NUM_DEFRAGED, msg_parms, 1, JFS_MSG);
 	else
 	{
-		message_user(MSG_JFS_NUM_CANDIDATE, msg_parms, 1, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
-
+		message_user(MSG_JFS_NUM_CANDIDATE, msg_parms, 1, JFS_MSG);
 		if (AG_DEFRAG)
 		{
 
@@ -604,8 +600,7 @@ jFYI(1,("\t%8d+   %12d   %7d\n", i, FSAllocRun[0], FSFreeRun[0]));
 			_itoa(total_free_runs/AG_DEFRAG, msgstr, 10);
 #endif 
 			msg_parms[0] = msgstr;
-			message_user(MSG_JFS_AVG_FREE_RUNS, msg_parms, 1,
-			     STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+			message_user(MSG_JFS_AVG_FREE_RUNS, msg_parms, 1, JFS_MSG);
 		}
 	}
 
@@ -1186,7 +1181,7 @@ static int32_t addDtree( dinode_t	*dip,
 	int8_t	  *stbl;
 	int32_t	  i;
 	pxd_t	  *pxd;
-	int64_t	  xaddr, lmxaddr;
+	int64_t	  xaddr, lmxaddr = 0;
 	int32_t	  xlen;
 	ixad_t	 *ixad;
 
@@ -1780,7 +1775,7 @@ static int32_t fscntlMove( int64_t	nxaddr,
 	                       int32_t	xlen, 
 	                       ixad_t	*ixad)
 {
-	int32_t	rc;
+	int32_t	rc = 0;
 
 #ifdef _JFS_OS2 
 	int32_t	       pList;
@@ -1959,8 +1954,7 @@ jEVENT(0,("preamble: sync.\n"));
 	if (rc)
 	{
 		msg_parms[0] = "Sync Failure";
-		message_user(MSG_JFS_UNEXPECTED_ERROR, msg_parms, 1,
-			     STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_UNEXPECTED_ERROR, msg_parms, 1, JFS_MSG);
 		return rc;
 	}
 
@@ -2065,8 +2059,7 @@ static int32_t getProvisions(void)
 
 	if ((ixadPool = (ixad_t *)malloc(nbytes)) == NULL)
 	{
-	message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, STDOUT_CODE,
-			     NO_RESPONSE, JFS_MSG);
+	message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, JFS_MSG);
 		return ERROR_NOT_ENOUGH_MEMORY;
 	}
 
