@@ -44,10 +44,6 @@
  */
 #include "xfsckint.h"
 
-/* endian routines */
-extern uint32_t type_jfs;
-extern void ujfs_swap_dbmap_t( dbmap_t * );
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
   * superblock buffer pointer
@@ -93,7 +89,6 @@ extern char message_parm_9[];
 extern char *msgprms[];
 extern int16_t msgprmidx[];
 
-extern char *terse_msg_ptr;
 extern char *verbose_msg_ptr;
 
 extern char *MsgText[];
@@ -189,9 +184,7 @@ retcode_t ctlpage_rebuild ( int8_t  max_buddy )
   if( bcr_rc == FSCK_OK ) {  /* got the control page in the buffer */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_dbmap_t( (dbmap_t *)bmap_recptr->bmpctl_bufptr );
-    } 
+    ujfs_swap_dbmap_t( (dbmap_t *)bmap_recptr->bmpctl_bufptr );
 
     bmap_recptr->bmpctl_bufptr->dn_mapsize = bmap_recptr->total_blocks;
     bmap_recptr->bmpctl_bufptr->dn_nfree = bmap_recptr->free_blocks;
@@ -262,9 +255,7 @@ retcode_t ctlpage_rebuild ( int8_t  max_buddy )
 	 */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dbmap_t( bmap_recptr->bmpctl_bufptr );
-    }
+    ujfs_swap_dbmap_t( bmap_recptr->bmpctl_bufptr );
 
     bcr_rc = mapctl_put( (void *) bmap_recptr->bmpctl_bufptr );
   }  /* end got the control page in the buffer */
@@ -302,22 +293,20 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
   if( bcv_rc == FSCK_OK ) {  /* got the control page in the buffer */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_dbmap_t( (dbmap_t *)bmap_recptr->bmpctl_bufptr );
-    } 
+    ujfs_swap_dbmap_t( (dbmap_t *)bmap_recptr->bmpctl_bufptr );
 
     if( bmap_recptr->bmpctl_bufptr->dn_mapsize != bmap_recptr->total_blocks ) { /*
 				* bad number of blocks in the aggregate
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCASB, 0, 0 );
+      fsck_send_msg( fsck_BMAPCASB, 0 );
     }  /* end bad number of blocks in the aggregate */
 
     if( bmap_recptr->bmpctl_bufptr->dn_nfree != bmap_recptr->free_blocks ) { /*
 				* bad number of free blocks in the aggregate
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCNF, 0, 0 );
+      fsck_send_msg( fsck_BMAPCNF, 0 );
     }  /* end bad number of free blocks in the aggregate */
 
     if( bmap_recptr->bmpctl_bufptr->dn_l2nbperpage !=
@@ -325,14 +314,14 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
 				* bad log2( blocks per page )
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCL2BPP, 0, 0 );
+      fsck_send_msg( fsck_BMAPCL2BPP, 0 );
     }  /* end bad log2( blocks per page ) */
 
     if( bmap_recptr->bmpctl_bufptr->dn_numag != agg_recptr->num_ag ) { /*
 				* bad number of alloc groups
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCNAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCNAG, 0 );
     }  /* end bad number of alloc groups */
 
     max_level = BMAPSZTOLEV( agg_recptr->sb_agg_fsblk_length );
@@ -340,7 +329,7 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
 				* bad maximum block map level
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCMXLVL, 0, 0 );
+      fsck_send_msg( fsck_BMAPCMXLVL, 0 );
     }  /* end bad maximum block map level */
 
     for( agidx = 0; (agidx < MAXAG); agidx++ ) {  /* check out the active AGs */
@@ -359,14 +348,14 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
 				* bad highest active alloc group
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCMAAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCMAAG, 0 );
     }  /* end bad highest active alloc group */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agpref > highest_active_AG ) { /*
 				* bad preferred alloc group
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCPAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCPAG, 0 );
     }  /* end bad preferred alloc group */
 
     aglevel = BMAPSZTOLEV(sb_ptr->s_agsize);
@@ -382,28 +371,28 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
 				* bad level holding an AG
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCDMCLAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCDMCLAG, 0 );
     }  /* end bad level holding an AG */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agheigth != agheight ) { /*
 				* bad dmapctl height holding an AG
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCDMCLH, 0, 0 );
+      fsck_send_msg( fsck_BMAPCDMCLH, 0 );
     }  /* end bad dmapctl height holding an AG */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agwidth != agwidth ) { /*
 				* bad width at level holding an AG
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCDMCLW, 0, 0 );
+      fsck_send_msg( fsck_BMAPCDMCLW, 0 );
     }  /* end bad width at level holding an AG */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agstart != agstart ) { /*
 				* bad start idx at level holding an AG
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCDMCSTI, 0, 0 );
+      fsck_send_msg( fsck_BMAPCDMCSTI, 0 );
     }  /* end bad start idx at level holding an AG */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agl2size !=
@@ -411,21 +400,21 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
 				* bad log2(fsblks per AG)
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCL2BPAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCL2BPAG, 0 );
     }  /* end bad log2(fsblks per AG) */
 
     if( bmap_recptr->bmpctl_bufptr->dn_agsize != sb_ptr->s_agsize ) {  /*
 				* bad fsblks per AG
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCBPAG, 0, 0 );
+      fsck_send_msg( fsck_BMAPCBPAG, 0 );
     }  /* end bad fsblks per AG */
 
     if( bmap_recptr->bmpctl_bufptr->dn_maxfreebud != max_buddy ) {  /*
 				* bad max free buddy system
 				*/
       bmap_recptr->ctl_other_error = -1;
-      fsck_send_msg( fsck_BMAPCBMXB, 0, 0 );
+      fsck_send_msg( fsck_BMAPCBMXB, 0 );
     }  /* end bad max free buddy system */
 
     for( agidx = 0; (agidx < MAXAG); agidx++ ) {  /* verify the free list */
@@ -437,7 +426,7 @@ retcode_t ctlpage_verify ( int8_t  max_buddy )
         sprintf( message_parm_0, "%d", agidx );
         msgprms[0] = message_parm_0;
         msgprmidx[0] = 0;
-        fsck_send_msg( fsck_BMAPCAGNF, 0, 1 );
+        fsck_send_msg( fsck_BMAPCAGNF, 1 );
 	  }  /* end bad free blocks in the AG */
     }  /* end verify the free list */
   }  /* end got the control page in the buffer */
@@ -604,7 +593,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
                 sprintf( message_parm_3, "%d", marked_range_bitidx );
                 msgprms[3] = message_parm_3;
                 msgprmidx[3] = 0;
-                fsck_send_msg( fsck_PMAPSBOFF, 0, 4 );
+                fsck_send_msg( fsck_PMAPSBOFF, 4 );
 		        size_of_marked_range = 0;
 		      }  /* end other range ended */
 
@@ -629,7 +618,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
               sprintf( message_parm_3, "%d", marked_range_bitidx );
               msgprms[3] = message_parm_3;
               msgprmidx[3] = 0;
-              fsck_send_msg( fsck_PMAPSBOFF, 0, 4 );
+              fsck_send_msg( fsck_PMAPSBOFF, 4 );
 	          size_of_marked_range = 0;
 	        }  /* end marked range ended */
 	        if( size_of_unmarked_range != 0 ) {  /* unmarked range ended */
@@ -645,7 +634,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
               sprintf( message_parm_3, "%d", unmarked_range_bitidx );
               msgprmidx[3] = 0;
               msgprms[3] = message_parm_3;
-              fsck_send_msg( fsck_PMAPSBON, 0, 4 );
+              fsck_send_msg( fsck_PMAPSBON, 4 );
 	          size_of_unmarked_range = 0;
 	        }  /* end unmarked range ended */
 	      }  /* end else pmap agrees */
@@ -674,7 +663,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
                 sprintf( message_parm_3, "%d", unmarked_range_bitidx );
                 msgprms[3] = message_parm_3;
                 msgprmidx[3] = 0;
-                fsck_send_msg( fsck_PMAPSBON, 0, 4 );
+                fsck_send_msg( fsck_PMAPSBON, 4 );
 		        size_of_unmarked_range = 0;
 		      }  /* end other range ended */
 
@@ -699,7 +688,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
               sprintf( message_parm_3, "%d", marked_range_bitidx );
               msgprms[3] = message_parm_3;
               msgprmidx[3] = 0;
-              fsck_send_msg( fsck_PMAPSBOFF, 0, 4 );
+              fsck_send_msg( fsck_PMAPSBOFF, 4 );
 	          size_of_marked_range = 0;
 	        }  /* end marked range ended */
 	        if( size_of_unmarked_range != 0 ) {  /* unmarked range ended */
@@ -715,7 +704,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
               sprintf( message_parm_3, "%d", unmarked_range_bitidx );
               msgprms[3] = message_parm_3;
               msgprmidx[3] = 0;
-              fsck_send_msg( fsck_PMAPSBON, 0, 4 );
+              fsck_send_msg( fsck_PMAPSBON, 4 );
 	          size_of_unmarked_range = 0;
 	        }  /* end unmarked range ended */
 	      }  /* end else pmap agrees */
@@ -738,7 +727,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
       sprintf( message_parm_3, "%d", marked_range_bitidx );
       msgprms[3] = message_parm_3;
       msgprmidx[3] = 0;
-      fsck_send_msg( fsck_PMAPSBOFF, 0, 4 );
+      fsck_send_msg( fsck_PMAPSBOFF, 4 );
       size_of_marked_range = 0;
     }  /* end marked range ended */
     if( size_of_unmarked_range != 0 ) {  /* unmarked range ended */
@@ -754,7 +743,7 @@ retcode_t dmap_pmap_verify ( reg_idx_t  *pmap_freeblks )
       sprintf( message_parm_3, "%d", unmarked_range_bitidx );
       msgprms[3] = message_parm_3;
       msgprmidx[3] = 0;
-      fsck_send_msg( fsck_PMAPSBON, 0, 4 );
+      fsck_send_msg( fsck_PMAPSBON, 4 );
       size_of_unmarked_range = 0;
     }  /* end unmarked range ended */
   }  /* end have the corresponding wsp map */
@@ -840,7 +829,7 @@ retcode_t dmap_tree_verify ( int8_t  *root_data )
     sprintf( message_parm_1, "%d", bmap_recptr->dmappg_ordno );
     msgprms[1] = message_parm_1;
     msgprmidx[1] = 0;
-    fsck_send_msg( fsck_BMAPBADNLF, 0, 2 );
+    fsck_send_msg( fsck_BMAPBADNLF, 2 );
   }  /* end wrong number of leafs */
 
   if( prms_ptr->buf_tree->dmt_l2nleafs != L2LPERDMAP ) { /* wrong log2(nleafs) */
@@ -851,7 +840,7 @@ retcode_t dmap_tree_verify ( int8_t  *root_data )
     sprintf( message_parm_1, "%d", bmap_recptr->dmappg_ordno );
     msgprms[1] = message_parm_1;
     msgprmidx[1] = 0;
-    fsck_send_msg( fsck_BMAPBADL2NLF, 0, 2 );
+    fsck_send_msg( fsck_BMAPBADL2NLF, 2 );
   }  /* end wrong log2(nleafs) */
 
   if( prms_ptr->buf_tree->dmt_leafidx != LEAFIND ) { /* wrong 1st leaf index */
@@ -862,7 +851,7 @@ retcode_t dmap_tree_verify ( int8_t  *root_data )
     sprintf( message_parm_1, "%d", bmap_recptr->dmappg_ordno );
     msgprms[1] = message_parm_1;
     msgprmidx[1] = 0;
-    fsck_send_msg( fsck_BMAPBADLFI, 0, 2 );
+    fsck_send_msg( fsck_BMAPBADLFI, 2 );
   }  /* end wrong 1st leaf index */
 
   if( prms_ptr->buf_tree->dmt_height != 4 ) { /* wrong stree height */
@@ -873,7 +862,7 @@ retcode_t dmap_tree_verify ( int8_t  *root_data )
     sprintf( message_parm_1, "%d", bmap_recptr->dmappg_ordno );
     msgprms[1] = message_parm_1;
     msgprmidx[1] = 0;
-    fsck_send_msg( fsck_BMAPBADHT, 0, 2 );
+    fsck_send_msg( fsck_BMAPBADHT, 2 );
   }  /* end wrong stree height */
 
   if( prms_ptr->buf_tree->dmt_budmin != BUDMIN ) { /* wrong min buddy value */
@@ -884,7 +873,7 @@ retcode_t dmap_tree_verify ( int8_t  *root_data )
     sprintf( message_parm_1, "%d", bmap_recptr->dmappg_ordno );
     msgprms[1] = message_parm_1;
     msgprmidx[2] = 0;
-    fsck_send_msg( fsck_BMAPBADBMN, 0, 2 );
+    fsck_send_msg( fsck_BMAPBADBMN, 2 );
   }  /* end wrong min buddy value */
 
     /*
@@ -1025,7 +1014,7 @@ retcode_t dmappg_verify ( int8_t  *stree_root_data )
       sprintf( message_parm_0, "%d", bmap_recptr->dmappg_ordno );
       msgprms[0] = message_parm_0;
       msgprmidx[0] = 0;
-      fsck_send_msg( fsck_DMAPBADSTRT, 0, 1 );
+      fsck_send_msg( fsck_DMAPBADSTRT, 1 );
     }  /* end bad starting block */
 
     nblocks = MIN( BPERDMAP,
@@ -1037,7 +1026,7 @@ retcode_t dmappg_verify ( int8_t  *stree_root_data )
       sprintf( message_parm_0, "%d", bmap_recptr->dmappg_ordno );
       msgprms[0] = message_parm_0;
       msgprmidx[0] = 0;
-      fsck_send_msg( fsck_DMAPBADNBLK, 0, 1 );
+      fsck_send_msg( fsck_DMAPBADNBLK, 1 );
     }  /* end bad number of blocks */
 
     bdmpv_rc = dmap_pmap_verify( &dmap_freeblks );
@@ -1067,7 +1056,7 @@ retcode_t dmappg_verify ( int8_t  *stree_root_data )
         sprintf( message_parm_0, "%d", bmap_recptr->dmappg_ordno );
         msgprms[0] = message_parm_0;
         msgprmidx[0] = 0;
-        fsck_send_msg( fsck_DMAPBADNFREE, 0, 1 );
+        fsck_send_msg( fsck_DMAPBADNFREE, 1 );
 	  }  /* end bad number of free blocks */
 
       bdmpv_rc = dmap_tree_verify( stree_root_data );
@@ -1333,7 +1322,7 @@ retcode_t Ln_tree_verify ( int         level,
       sprintf( message_parm_1, "%d", prms_ptr->page_ordno );
       msgprms[1] = message_parm_1;
       msgprmidx[1] = 0;
-      fsck_send_msg( fsck_BMAPBADNLF, 0, 2 );
+      fsck_send_msg( fsck_BMAPBADNLF, 2 );
     }  /* end wrong number of leafs */
 
     if( prms_ptr->buf_tree->dmt_l2nleafs != L2LPERCTL ) { /* wrong log2(nleafs) */
@@ -1344,7 +1333,7 @@ retcode_t Ln_tree_verify ( int         level,
       sprintf( message_parm_1, "%d", prms_ptr->page_ordno );
       msgprms[1] = message_parm_1;
       msgprmidx[1] = 0;
-      fsck_send_msg( fsck_BMAPBADL2NLF, 0, 2 );
+      fsck_send_msg( fsck_BMAPBADL2NLF, 2 );
     }  /* end wrong log2(nleafs) */
 
     if( prms_ptr->buf_tree->dmt_leafidx != CTLLEAFIND ) { /*
@@ -1356,7 +1345,7 @@ retcode_t Ln_tree_verify ( int         level,
       sprintf( message_parm_1, "%d", prms_ptr->page_ordno );
       msgprms[1] = message_parm_1;
       msgprmidx[1] = 0;
-      fsck_send_msg( fsck_BMAPBADLFI, 0, 2 );
+      fsck_send_msg( fsck_BMAPBADLFI, 2 );
     }  /* end wrong 1st leaf index */
 
     if( prms_ptr->buf_tree->dmt_height != 5 ) { /* wrong stree height */
@@ -1367,7 +1356,7 @@ retcode_t Ln_tree_verify ( int         level,
       sprintf( message_parm_1, "%d", prms_ptr->page_ordno );
       msgprms[1] = message_parm_1;
       msgprmidx[1] = 0;
-      fsck_send_msg( fsck_BMAPBADHT, 0, 2 );
+      fsck_send_msg( fsck_BMAPBADHT, 2 );
     }  /* end wrong stree height */
 
     if( prms_ptr->buf_tree->dmt_budmin != (L2BPERDMAP + level * L2LPERCTL) ) { /*
@@ -1380,7 +1369,7 @@ retcode_t Ln_tree_verify ( int         level,
       sprintf( message_parm_1, "%d", prms_ptr->page_ordno );
       msgprms[1] = message_parm_1;
       msgprmidx[1] = 0;
-      fsck_send_msg( fsck_BMAPBADBMN, 0, 2 );
+      fsck_send_msg( fsck_BMAPBADBMN, 2 );
     }  /* end wrong min buddy value */
 
       /*
@@ -1679,7 +1668,7 @@ retcode_t stree_verify ( fsck_stree_parms_ptr  prms_ptr,
       sprintf( message_parm_2, "%d", prms_ptr->page_ordno );
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BMAPBADLNV, 0, 3 );
+      fsck_send_msg( fsck_BMAPBADLNV, 3 );
     }  /* end they don't match! */
   }  /* end for node_idx = root and all internal nodes */
 
@@ -1699,7 +1688,7 @@ retcode_t stree_verify ( fsck_stree_parms_ptr  prms_ptr,
       sprintf( message_parm_2, "%d", prms_ptr->page_ordno );
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BMAPBADLFV, 0, 3 );
+      fsck_send_msg( fsck_BMAPBADLFV, 3 );
     }  /* end they don't match! */
   }  /* end for node_idx = leaf nodes */
 
@@ -1898,73 +1887,73 @@ retcode_t verify_blkall_summary_msgs ( )
   retcode_t  vbsm_rc = FSCK_OK;
 
   if( bmap_recptr->dmap_pmap_error ) {
-    fsck_send_msg( fsck_BADDMAPPMAPS, 0, 0 );
+    fsck_send_msg( fsck_BADDMAPPMAPS, 0 );
   }
   if( bmap_recptr->dmap_slfv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_dmap;
-    fsck_send_msg( fsck_BADBMAPSLFV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLFV, 1 );
   }
   if( bmap_recptr->dmap_slnv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_dmap;
-    fsck_send_msg( fsck_BADBMAPSLNV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLNV, 1 );
   }
   if( bmap_recptr->dmap_other_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_dmap;
-    fsck_send_msg( fsck_BADBMAPSOTHER, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSOTHER, 1 );
   }
   if( bmap_recptr->L0pg_slfv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L0;
-    fsck_send_msg( fsck_BADBMAPSLFV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLFV, 1 );
   }
   if( bmap_recptr->L0pg_slnv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L0;
-    fsck_send_msg( fsck_BADBMAPSLNV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLNV, 1 );
   }
   if( bmap_recptr->L0pg_other_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L0;
-    fsck_send_msg( fsck_BADBMAPSOTHER, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSOTHER, 1 );
   }
   if( bmap_recptr->L1pg_slfv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L1;
-    fsck_send_msg( fsck_BADBMAPSLFV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLFV, 1 );
   }
   if( bmap_recptr->L1pg_slnv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L1;
-    fsck_send_msg( fsck_BADBMAPSLNV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLNV, 1 );
   }
   if( bmap_recptr->L1pg_other_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L1;
-    fsck_send_msg( fsck_BADBMAPSOTHER, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSOTHER, 1 );
   }
   if( bmap_recptr->L2pg_slfv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L2;
-    fsck_send_msg( fsck_BADBMAPSLFV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLFV, 1 );
   }
   if( bmap_recptr->L2pg_slnv_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L2;
-    fsck_send_msg( fsck_BADBMAPSLNV, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSLNV, 1 );
   }
   if( bmap_recptr->L2pg_other_error ) {
     msgprms[0] = message_parm_0;
     msgprmidx[0] = fsck_L2;
-    fsck_send_msg( fsck_BADBMAPSOTHER, 0, 1 );
+    fsck_send_msg( fsck_BADBMAPSOTHER, 1 );
   }
   if( bmap_recptr->ctl_fctl_error ) {
-    fsck_send_msg( fsck_BADBMAPCAGFCL, 0, 0 );
+    fsck_send_msg( fsck_BADBMAPCAGFCL, 0 );
   }
   if( bmap_recptr->ctl_other_error ) {
-    fsck_send_msg( fsck_BADBMAPCOTH, 0, 0 );
+    fsck_send_msg( fsck_BADBMAPCOTH, 0 );
   }
   if( bmap_recptr->dmap_pmap_error  || bmap_recptr->dmap_slfv_error  ||
       bmap_recptr->dmap_slnv_error  || bmap_recptr->dmap_other_error ||
@@ -1974,11 +1963,11 @@ retcode_t verify_blkall_summary_msgs ( )
       bmap_recptr->L2pg_slfv_error  || bmap_recptr->L2pg_slnv_error  ||
       bmap_recptr->L2pg_other_error                                     ) {
     agg_recptr->ag_dirty = 1;
-    fsck_send_msg( fsck_BADBLKALLOC, 0, 0 );
+    fsck_send_msg( fsck_BADBLKALLOC, 0 );
   }
   if( bmap_recptr->ctl_fctl_error || bmap_recptr->ctl_other_error ) {
     agg_recptr->ag_dirty = 1;
-    fsck_send_msg( fsck_BADBLKALLOCCTL, 0, 0 );
+    fsck_send_msg( fsck_BADBLKALLOCCTL, 0 );
   }
   return( vbsm_rc );
 }  /* end of verify_blkall_summary_msgs () */
