@@ -70,7 +70,6 @@ extern char message_parm_9[];
 extern char *msgprms[];
 extern int16_t  msgprmidx[];
 
-extern char *terse_msg_ptr;
 extern char *verbose_msg_ptr;
 
 extern char *MsgText[];
@@ -172,7 +171,7 @@ retcode_t adjust_parent ( inoidx_t           child_ino,
     sprintf( message_parm_3, "%d", 0 );                                        
     msgprms[3] = message_parm_3;                                               
     msgprmidx[3] = 0;                                                          
-    fsck_send_msg( fsck_INTERNALERROR, 0, 4 );                        
+    fsck_send_msg( fsck_INTERNALERROR, 4 );                        
 
   } else if( adjp_rc == FSCK_OK ) {  /* located the parent's inode record */
     adjp_rc = get_inode_extension( &this_ext );
@@ -387,7 +386,7 @@ retcode_t check_connectedness ( )
         sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
         msgprms[1] = message_parm_1;
         msgprmidx[1] = 0;
-        fsck_send_msg( fsck_INONOPATHS, 0, 2 );
+        fsck_send_msg( fsck_INONOPATHS, 2 );
 
       } else {  /* at least one parent observed by fsck */
         cc_rc = reset_parents( this_inorec, ino_idx );  /*
@@ -432,7 +431,7 @@ retcode_t check_connectedness ( )
                 sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
                 msgprms[1] = message_parm_1;
                 msgprmidx[1] = 0;
-                fsck_send_msg( fsck_WILLFIXDIRWHDLKS, 0, 2 );
+                fsck_send_msg( fsck_WILLFIXDIRWHDLKS, 2 );
 
               } else {       /* we don't have write access */
                 this_inorec->unxpctd_prnts = 0;
@@ -442,7 +441,7 @@ retcode_t check_connectedness ( )
                 sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
                 msgprms[1] = message_parm_1;
                 msgprmidx[1] = 0;
-                fsck_send_msg( fsck_DIRWHDLKS, 0, 2 );
+                fsck_send_msg( fsck_DIRWHDLKS, 2 );
               }  /* end we don't have write access */
             }  /* end nothing unexpected */
 
@@ -458,7 +457,7 @@ retcode_t check_connectedness ( )
               sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
               msgprms[1] = message_parm_1;
               msgprmidx[1] = 0;
-              fsck_send_msg( fsck_WILLFIXINCREF, 0, 2 );
+              fsck_send_msg( fsck_WILLFIXINCREF, 2 );
             } else {       /* we don't have write access */
               this_inorec->crrct_prnt_inonum = 0;
               agg_recptr->ag_dirty = 1;
@@ -467,7 +466,7 @@ retcode_t check_connectedness ( )
               sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
               msgprms[1] = message_parm_1;
               msgprmidx[1] = 0;
-              fsck_send_msg( fsck_INCINOREF, 0, 2 );
+              fsck_send_msg( fsck_INCINOREF, 2 );
             }  /* end we don't have write access */
           }  /* end a single parent but not the one named....  */
         }  /* end else still connected */
@@ -597,7 +596,7 @@ retcode_t check_dir_integrity ( )
                   sprintf( message_parm_3, "%d", 37 );
                   msgprms[3] = message_parm_3;
                   msgprmidx[3] = 0;
-                  fsck_send_msg( fsck_BADKEYS, 0, 4 );
+                  fsck_send_msg( fsck_BADKEYS, 4 );
                 }  /* end dup_parent_detected */
               }  /* end parent isn't marked for release (yet) */
             }  /* end a parent */
@@ -704,7 +703,7 @@ retcode_t check_link_counts ( )
           sprintf( message_parm_3, "%d", 0 );                           
           msgprms[3] = message_parm_3;                                  
           msgprmidx[3] = 0;                                             
-          fsck_send_msg( fsck_INTERNALERROR, 0, 4 );                    
+          fsck_send_msg( fsck_INTERNALERROR, 4 );                    
         } else {
           parent_inorec->link_count++; /*
                                * handle the first (and usually the only)
@@ -755,7 +754,7 @@ retcode_t check_link_counts ( )
                     sprintf( message_parm_3, "%d", 0 );                     
                     msgprms[3] = message_parm_3;                            
                     msgprmidx[3] = 0;                                       
-                    fsck_send_msg( fsck_INTERNALERROR, 0, 4 );              
+                    fsck_send_msg( fsck_INTERNALERROR, 4 );              
                   } else {
                     parent_inorec->link_count++;
                   }
@@ -807,7 +806,7 @@ retcode_t check_link_counts ( )
             sprintf( message_parm_1, "%d", ino_idx );
             msgprms[1] = message_parm_1;
             msgprmidx[1] = 0;
-            fsck_send_msg( fsck_BADINOLKCT, 0, 2 );
+            fsck_send_msg( fsck_BADINOLKCT, 2 );
           }  /* end else not an orphan */
         }  /* end stored link count doesn't match fsck's observations */
       }  /* end inode is in use and not being released */
@@ -821,7 +820,7 @@ retcode_t check_link_counts ( )
 
       if( agg_recptr->processing_readwrite ) {  /* we can fix this */
         agg_recptr->corrections_approved = 1;
-        fsck_send_msg( fsck_WILLFIXLINKCTS, 0, 0 );
+        fsck_send_msg( fsck_WILLFIXLINKCTS, 0 );
       } else {  /* no write access */
         if( low_stored_count_seen )  {
           agg_recptr->ag_dirty = 1;
@@ -847,7 +846,7 @@ retcode_t check_link_counts ( )
 
           clc_rc = get_inorecptr_next( aggregate_inode, &ino_idx, &this_inorec );
         }  /* end while */
-        fsck_send_msg( fsck_BADLINKCTS, 0, 0 );
+        fsck_send_msg( fsck_BADLINKCTS, 0 );
       }  /* end no write access */
     }  /* end if invalid_count_seen */
   }  /* end no fatal errors */
@@ -917,7 +916,7 @@ retcode_t reset_parents ( fsck_inode_recptr  ino_recptr,
       sprintf( message_parm_3, "%d", 0 );                              
       msgprms[3] = message_parm_3;                                     
       msgprmidx[3] = 0;                                                
-      fsck_send_msg( fsck_INTERNALERROR, 0, 4 );                       
+      fsck_send_msg( fsck_INTERNALERROR, 4 );                       
 
     } else if( resps_rc == FSCK_OK ) {
       if( (ino_recptr->parent_inonum == ROOT_I) &&
@@ -969,7 +968,7 @@ retcode_t reset_parents ( fsck_inode_recptr  ino_recptr,
         sprintf( message_parm_3, "%d", 0 );                             
         msgprms[3] = message_parm_3;                                    
         msgprmidx[3] = 0;                                               
-        fsck_send_msg( fsck_INTERNALERROR, 0, 4 );                      
+        fsck_send_msg( fsck_INTERNALERROR, 4 );                      
 
       } else if( resps_rc == FSCK_OK ) {
         if( (ino_recptr->parent_inonum == ROOT_I) &&
