@@ -79,7 +79,6 @@ extern char message_parm_9[];
 extern char  *msgprms[];
 extern int16_t  msgprmidx[];
 
-extern char *terse_msg_ptr;
 extern char *verbose_msg_ptr;
 
 extern char *MsgText[];
@@ -513,7 +512,7 @@ retcode_t xTree_node_first_key ( fsck_Xtree_info_ptr  xtiptr,
       sprintf( message_parm_3, "%d", 5 );
       msgprms[3] = message_parm_3;
       msgprmidx[3] = 0;
-      fsck_send_msg( fsck_BADKEYS, 0, 4 );
+      fsck_send_msg( fsck_BADKEYS, 4 );
     }  /* end not reported yet */
   } else {  /* 1st xad might be ok */
     if( xtiptr->last_level == xtiptr->this_Qel->node_level ) {  /*
@@ -538,7 +537,7 @@ retcode_t xTree_node_first_key ( fsck_Xtree_info_ptr  xtiptr,
             sprintf( message_parm_2, "%lld", (long long)xtiptr->last_key );
             msgprms[2] = message_parm_2;
             msgprmidx[2] = 0;
-            fsck_send_msg( fsck_BADINOINTERNGAP, 0, 3 );
+            fsck_send_msg( fsck_BADINOINTERNGAP, 3 );
           }  /* end not reported yet */
         }  /* end a gap in a dense file */
       } else {  /* not a leaf node in a dense file */
@@ -559,7 +558,7 @@ retcode_t xTree_node_first_key ( fsck_Xtree_info_ptr  xtiptr,
             sprintf( message_parm_3, "%d", 6 );
             msgprms[3] = message_parm_3;
             msgprmidx[3] = 0;
-            fsck_send_msg( fsck_BADKEYS, 0, 4 );
+            fsck_send_msg( fsck_BADKEYS, 4 );
           }  /* end not reported yet */
         }  /* end the extents overlap! */
       }  /* end else not a leaf node in a dense file */
@@ -611,7 +610,7 @@ retcode_t xTree_node_first_in_level ( fsck_Xtree_info_ptr  xtiptr,
       sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum);
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BADBSBLCHN, 0, 3 );
+      fsck_send_msg( fsck_BADBSBLCHN, 3 );
     }  /* end not reported yet */
   }  /* end bad back ptr! */
 
@@ -661,7 +660,7 @@ retcode_t xTree_node_last_in_level ( fsck_Xtree_info_ptr  xtiptr,
       sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum );
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BADFSBLCHN, 0, 3 );
+      fsck_send_msg( fsck_BADFSBLCHN, 3 );
     }  /* end not reported yet */
   }  /* end bad forward ptr!  */
 
@@ -710,7 +709,7 @@ retcode_t xTree_node_not_first_in_level ( fsck_Xtree_info_ptr  xtiptr,
       sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum);
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BADBSBLCHN, 0, 3 );
+      fsck_send_msg( fsck_BADBSBLCHN, 3 );
     }  /* end not reported yet */
   }  /* end bad back ptr! */
 
@@ -760,7 +759,7 @@ retcode_t xTree_node_not_last_in_level ( fsck_Xtree_info_ptr  xtiptr,
       sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum );
       msgprms[2] = message_parm_2;
       msgprmidx[2] = 0;
-      fsck_send_msg( fsck_BADFSBLCHN, 0, 3 );
+      fsck_send_msg( fsck_BADFSBLCHN, 3 );
     }  /* end not reported yet */
   } else {  /* forward sibling pointer is correct */
     if( xtiptr->this_Qel->last_ext_uneven )  {  /* last extent described
@@ -789,7 +788,7 @@ retcode_t xTree_node_not_last_in_level ( fsck_Xtree_info_ptr  xtiptr,
         sprintf( message_parm_4, "%d", xtiptr->ext_length );
         msgprms[4] = message_parm_4;
         msgprmidx[4] = 0;
-        fsck_send_msg( fsck_BADINOODDINTRNEXT, 0, 5 );
+        fsck_send_msg( fsck_BADINOODDINTRNEXT, 5 );
       }  /* end not reported yet */
     }  /* end last extent described by this node is ... */
   }  /* end else forward sibling pointer is correct */
@@ -870,7 +869,7 @@ retcode_t xTree_process_internal_extents ( xtpage_t           *xtpg_ptr,
           sprintf( message_parm_3, "%d", 7 );
           msgprms[3] = message_parm_3;
           msgprmidx[3] = 0;
-          fsck_send_msg( fsck_BADKEYS, 0, 4 );
+          fsck_send_msg( fsck_BADKEYS, 4 );
         }  /* end first detection */
       } else {  /* key looks ok from here */
         last_key = this_key;
@@ -986,7 +985,7 @@ retcode_t xTree_process_leaf_extents ( xtpage_t           *xtpg_ptr,
           sprintf( message_parm_3, "%d", 8 );
           msgprms[3] = message_parm_3;
           msgprmidx[3] = 0;
-          fsck_send_msg( fsck_BADKEYS, 0, 4 );
+          fsck_send_msg( fsck_BADKEYS, 4 );
         }  /* end first detection */
       } else {  /* the keys do ascend */
         if( (dense_file) && (this_key != (last_key + 1)) ) {  /*
@@ -1002,7 +1001,7 @@ retcode_t xTree_process_leaf_extents ( xtpage_t           *xtpg_ptr,
             sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum );
             msgprms[2] = message_parm_2;
             msgprmidx[2] = 0;
-            fsck_send_msg( fsck_BADINOINTERNGAP, 0, 3 );
+            fsck_send_msg( fsck_BADINOINTERNGAP, 3 );
           }  /* end first detection */
         }  /* end a dense file with a gap! */
       }  /* end else the keys do ascend */
@@ -1044,7 +1043,7 @@ retcode_t xTree_process_leaf_extents ( xtpage_t           *xtpg_ptr,
             sprintf( message_parm_4, "%d", ext_length );
             msgprms[4] = message_parm_4;
             msgprmidx[4] = 0;
-            fsck_send_msg( fsck_BADINOODDINTRNEXT, 0, 5 );
+            fsck_send_msg( fsck_BADINOODDINTRNEXT, 5 );
           }  /* end first detection */
         }  /* end else not the last extent for the xtpage */
       }  /* end this one is an odd size and isn't owned by the ... */
@@ -1167,7 +1166,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
       sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
       msgprms[3] = message_parm_3;
       msgprmidx[3] = 0;
-      fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+      fsck_send_msg( fsck_BADINOOTHR, 4 );
     }  /* end not reported yet */
   } else if( xtiptr->xtp_ptr->header.nextindex > xtiptr->xtp_ptr->header.maxentry ) {  /*
                               * bad nextindex field
@@ -1185,7 +1184,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
       sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
       msgprms[3] = message_parm_3;
       msgprmidx[3] = 0;
-      fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+      fsck_send_msg( fsck_BADINOOTHR, 4 );
     }  /* end not reported yet */
   }  /* end bad nextindex field */
  	
@@ -1217,7 +1216,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
         sprintf( message_parm_1, "%d", msg_info_ptr->msg_inonum );
         msgprms[1] = message_parm_1;
         msgprmidx[1] = 0;
-        fsck_send_msg( fsck_BADINOFRONTGAP, 0, 2 );
+        fsck_send_msg( fsck_BADINOFRONTGAP, 2 );
       }  /* end not reported yet */
     } else {  /* not a dense file with a gap at the front */
       xp_rc = treeQ_get_elem( &xtiptr->this_Qel );
@@ -1261,7 +1260,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
               sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
               msgprms[3] = message_parm_3;
               msgprmidx[3] = 0;
-              fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+              fsck_send_msg( fsck_BADINOOTHR, 4 );
             }  /* end not reported yet */
           }  /* end else invalid flag value! */
         }  /* end else root is not a leaf */
@@ -1329,7 +1328,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
  	          sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
  	          msgprms[3] = message_parm_3;
  	          msgprmidx[3] = 0;
- 	          fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+ 	          fsck_send_msg( fsck_BADINOOTHR, 4 );
             }  /* end not reported yet */
  	      } else {  /* got the new node */
             if( xtiptr->xtp_ptr->header.maxentry != XTPAGEMAXSLOT ) {  /*
@@ -1348,7 +1347,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
                 sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
                 msgprms[3] = message_parm_3;
                 msgprmidx[3] = 0;
-                fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+                fsck_send_msg( fsck_BADINOOTHR, 4 );
               }  /* end not reported yet */
             } else if( xtiptr->xtp_ptr->header.nextindex >
                        xtiptr->xtp_ptr->header.maxentry ) {  /*
@@ -1367,7 +1366,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
                 sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
                 msgprms[3] = message_parm_3;
                 msgprmidx[3] = 0;
-                fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+                fsck_send_msg( fsck_BADINOOTHR, 4 );
               }  /* end not reported yet */
             }  /* end bad nextindex field */
  	
@@ -1400,7 +1399,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
                   sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum );
                   msgprms[2] = message_parm_2;
                   msgprmidx[2] = 0;
-                  fsck_send_msg( fsck_BADINONODESELF, 0, 3 );
+                  fsck_send_msg( fsck_BADINONODESELF, 3 );
                 }  /* end not reported yet */
               } else if( xtiptr->xtp_ptr->header.nextindex > XTENTRYSTART )  {
                 if( xtiptr->xtp_ptr->header.flag & BT_LEAF ) {  /* it's a leaf */
@@ -1430,7 +1429,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
                   sprintf( message_parm_2, "%d", msg_info_ptr->msg_inonum );
                   msgprms[2] = message_parm_2;
                   msgprmidx[2] = 0;
-                  fsck_send_msg( fsck_BADINOMTNODE, 0, 3 );
+                  fsck_send_msg( fsck_BADINOMTNODE, 3 );
                 }  /* end not reported yet */
               }  /* end else an empty non-root node */
             }  /* end nothing major so far */
@@ -1479,7 +1478,7 @@ retcode_t xTree_processing ( dinode_t           *inoptr,
               sprintf( message_parm_3, "%d", msg_info_ptr->msg_inonum );
               msgprms[3] = message_parm_3;
               msgprmidx[3] = 0;
-              fsck_send_msg( fsck_BADINOOTHR, 0, 4 );
+              fsck_send_msg( fsck_BADINOOTHR, 4 );
             }  /* end not reported yet */
           }  /* end else an invalid flag value! */
         }  /* end else not a leaf node */
