@@ -157,9 +157,8 @@ extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
   * MsgProtocol[][], which is defined in fsckmsgp.h
   *
   */
-#define MP_STREAM     0
-#define MP_MSGLVL     1
-#define MP_MSGFILE    2
+#define MP_MSGLVL     0
+#define MP_MSGFILE    1
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
   *
@@ -171,19 +170,15 @@ extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
 /*
  * special cases (must not match any other constants in the table)
  */
-#define fsck_suffix            128
-#define fsck_notqry            129
-#define fsck_hrtbt             130
-#define fsck_txtins            131
+#define fsck_hrtbt     130
+#define fsck_txtins    131
 
 /*
  * The lowest messaging level (dictated by input parms) at which
  * the message is displayed.
  */
 #define fsck_quiet       2
-#define fsck_terse       4
 #define fsck_verbose     8
-#define fsck_autochk    16
 #define fsck_debug      32
 
 /*
@@ -195,20 +190,6 @@ extern int jfs_ValidateFEAList( FEALIST *, unsigned long * );
 #define no_msgfile      -1
 #define jfs_msgfile      1
 
-/*
- * Whether the message is English-only (intended for debugging purposes) or
- * needs to be displayed in the local language.
- */
-#define fsck_engl_only      0
-#define fsck_local_lang     1
-
-/*
- * constants to select standard I/O stream
- */
-#define fsck_out        0
-#define fsck_err        1
-#define fsck_in         2
-
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  * The following are used for reporting storage allocation
  * failures.
@@ -426,16 +407,24 @@ typedef struct fsck_imap_msg_info *fsck_imap_msg_info_ptr;
 #define fsck_longdata_and_otherinline  1
 
 
- /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
-  *
-  * The following define return codes passed back by fsck when an
-  * is detected in or by fsck.
-  *
-  */
+/* + + + + + + + + + + + + + + + + + + + + + + + + + + + +
+ *
+ * The following define exit codes passed back by fsck.jfs 
+ * and return codes passed internally in fsck.jfs.
+ *
+ */
+
+/* exit codes */
+
+#define FSCK_OK                    0
+#define FSCK_CORRECTED             1
+#define FSCK_REBOOT                2
+#define FSCK_ERRORS_UNCORRECTED    4
+#define FSCK_OP_ERROR              8
+#define FSCK_USAGE_ERROR          16
 
 /* informational return codes */
 
-#define FSCK_OK                   00000
 #define FSCK_FAILED              -00001
 
 #define FSCK_AGFS_INOBAD          10001
