@@ -35,6 +35,7 @@
 #include "fsckmsgc.h"
 #include "fsckpfs.h"
 #include "fsckwsp.h"
+#include "jfs_endian.h"
 
 /*
   ---------------------- functions defined in fsckbmap ---------------------
@@ -205,7 +206,7 @@ retcode_t validate_select_agg_inode_table ( void );
   ---------------------- functions defined in fsckmsgs ---------------------
 */
 
-void fsck_send_msg( int, int, int );
+void fsck_send_msg( int, int );
 
 /*
   ---------------------- functions defined in fsckpfs ---------------------
