@@ -46,8 +46,13 @@
 
                                
 int32_t ujfs_get_dev_size( HFILE device, int64_t * size );
-int32_t ujfs_open_device( char * Device, PHFILE FileHandle, int32_t * SectorSize, int32_t mode );
-int32_t ujfs_close( HFILE );
 int32_t ujfs_rw_diskblocks( HFILE, int64_t, int32_t, void *, int32_t );
 
+/*
+ * Convert st_rdev from stat() & fstat() to kernel-compatible device number
+ */
+static inline int32_t dev_to_kdev(dev_t rdev)
+{
+	return (major(rdev) << 8 | minor(rdev));
+}
 #endif /* H_DEVICES */
