@@ -295,7 +295,7 @@ Inode Allocation Group %s, Extent Index %s).\n"
 /*115*/
    ,"FSCK Mutually exclusive 'check READ ONLY' and 'fix file system' options specified.\n"
 /*116*/
-   ,"FSCK Usage: fsck.jfs [-a] [-f] [-n] [-o] [-p] [-v] [-V] <device>\n"
+   ,"FSCK   *undefined* \n"
 /*117*/
    ,"FSCK Unrecognized FSCK -f parameter value detected:   %s\n"
 /*118*/
@@ -326,7 +326,7 @@ Continuing.\n"
 /*130*/
    ,"FSCK  Primary superblock is valid.\n"
 /*131*/
-   ,"FSCK  processing terminated:  %s   with return code: %s.\n"
+   ,"FSCK  processing terminated:  %s  with return code: %s  exit code: %s.\n"
 /*132*/
    ,"FSCK  Close returned rc = %s\n"
 /*133*/
