@@ -18,6 +18,8 @@
  *	fssubs.c: fs utility subroutines
  */
 
+#include "config.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
@@ -26,16 +28,25 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <mntent.h>
 
-#include "jfs_byteorder.h"
+#if HAVE_MNTENT_H
+#include <mntent.h>
+#undef HAVE_GETMNTINFO	/* we don't want both */
+#endif
+
+#if HAVE_GETMNTINFO
+#include <paths.h>
+#include <sys/param.h>
+#include <sys/mount.h>
+#endif
+
+#include "jfs_endian.h"
 #include "jfs_types.h"
 #include "jfs_superblock.h"
 #include "jfs_filsys.h"
 #include "jfs_dinode.h"
 #include "jfs_dmap.h"
 #include "jfs_imap.h"
-#include "jfs_debug.h"
 
 #include "devices.h"
 #include "debug.h"
@@ -75,15 +86,6 @@ int64_t	     IMapXtreeLMLeaf; /* imap xtree leftmost leaf */
 xtpage_t	 IMapXtreeLeaf;   /* imap xtree leaf buffer */
 IMapXtree_t	 IMapXtree = {&IMapXtreeLeaf, XTENTRYSTART, 1};
 
-/* endian routines */
-extern uint32_t type_jfs;
-extern void ujfs_swap_dbmap_t( dbmap_t * );
-extern void ujfs_swap_dmapctl_t( dmapctl_t * );
-extern void ujfs_swap_dmap_t( dmap_t * );
-extern void ujfs_swap_dinomap_t( dinomap_t * );
-extern void ujfs_swap_iag_t( iag_t * );
-extern void ujfs_swap_xtpage_t( xtpage_t * );
-
 extern int errno;
 
 /*
@@ -92,7 +94,6 @@ extern int errno;
 int32_t openLV(char	 *LVName)
 {
 	int32_t	 rc = 0;
-	int32_t	 pbsize;
 	int64_t	 LVSize;
      
     if ( ( rc = Is_Device_Mounted( LVName )) == MSG_JFS_VOLUME_IS_MOUNTED ) {   /* is mounted */
@@ -110,21 +111,20 @@ int32_t openLV(char	 *LVName)
         return -1;
     }
 
-	/* open the device and get its physical block size */
-	if (( rc = ujfs_open_device(LVName, &LVHandle, &pbsize, READONLY) ))    {
+	LVHandle = open(LVName, O_RDONLY, 0);
+	if (LVHandle < 0) {
 		if (!Fail_Quietly)
-			message_user(MSG_OSO_CANT_OPEN, NULL, 0, STDOUT_CODE,
-				     NO_RESPONSE, OSO_MSG);
+			message_user(MSG_OSO_CANT_OPEN, NULL, 0, OSO_MSG);
 		return rc;
 	}
 
-	LVMount.pbsize = pbsize;
-	LVMount.l2pbsize = log2shift(pbsize);
+	LVMount.pbsize = PBSIZE;
+	LVMount.l2pbsize = log2shift(LVMount.pbsize);
      
 	/* get logical volume size */
 	if (( rc = ujfs_get_dev_size(LVHandle, &LVSize)) )    {
-		message_user(MSG_OSO_ERR_ACCESSING_DISK, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-		ujfs_close(LVHandle);
+		message_user(MSG_OSO_ERR_ACCESSING_DISK, NULL, 0, OSO_MSG);
+		close(LVHandle);
 		return rc;
 	}
 
@@ -160,13 +160,13 @@ int32_t openFS(void)
 
 	/* check magic/version number */
 	if (strncmp(sb->s_magic,JFS_MAGIC,(unsigned)strlen(JFS_MAGIC))
-	    || (sb->s_version != JFS_VERSION))    {
-		message_user(MSG_JFS_BAD_SUPERBLOCK, NULL, 0, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+	    || (sb->s_version > JFS_VERSION))    {
+		message_user(MSG_JFS_BAD_SUPERBLOCK, NULL, 0, JFS_MSG);
 		return -1;
 	}
 
 	if (sb->s_state & FM_DIRTY)    {
-		message_user(MSG_JFS_DIRTY, NULL, 0, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+		message_user(MSG_JFS_DIRTY, NULL, 0, JFS_MSG);
 		return -1;
 	}
 
@@ -192,7 +192,7 @@ int32_t openFS(void)
  */
 void closeFS(void)
 {
-	ujfs_close(LVHandle);
+	close(LVHandle);
 }
 
 
@@ -226,9 +226,7 @@ int32_t readBMapGCP(BMap_t  *bMap)
 	bcp = (dbmap_t *)bMap;
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
         ujfs_swap_dbmap_t( bcp );
-    }
 
 	fsMount->nAG = bcp->dn_numag;
 
@@ -273,9 +271,7 @@ int32_t readBMapLCP( int64_t	bn,
 	}
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
         ujfs_swap_dmapctl_t( lcp );
-    }
 
 	return 0;
 }
@@ -315,9 +311,7 @@ int32_t readBMap( int64_t  start_dmap,  /* the dmap number to start read */
 		}
 
         /* swap if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) {
             ujfs_swap_dmap_t( dmap );
-        }
 
 		xoff += xlen;
 		dmap = (dmap_t *)((char *)dmap + PAGESIZE);
@@ -352,9 +346,7 @@ int32_t readIMapGCPSequential( IMap_t  *iMap,
 	rc = pRead(fsMount, xaddr, fsMount->nbperpage, (void *)iMap);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
         ujfs_swap_dinomap_t( &(iMap->ctl) );
-    }
 
 	/* init for start of bitmap page read */
 	IAGNumber = 0;
@@ -406,9 +398,7 @@ int32_t readIMapSequential(iag_t  *iag)
 				       (void *)iag);
 
             /* swap if on big endian machine */
-            if (type_jfs & JFS_SWAP_BYTES) {
                 ujfs_swap_iag_t( iag );
-            }
 
 			if ( rc != 0 ) {
 				return rc;
@@ -451,9 +441,7 @@ int32_t readIMapSequential(iag_t  *iag)
 			       (void *)&IMapXtreeLeaf);
 
         /* swap if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) {
             ujfs_swap_xtpage_t( &IMapXtreeLeaf );
-        }
 
 		if ( rc != 0 ) {
 			return rc;
@@ -496,9 +484,7 @@ int32_t xtLMLeaf( dinode_t	*dip,	/* disk inode */
 	    	}
 
             /* swap if on big endian machine */
-            if (type_jfs & JFS_SWAP_BYTES) {
                 ujfs_swap_xtpage_t( pp );
-            }
 
             /* is this page leaf ? */
             if (pp->header.flag & BT_LEAF)
@@ -700,7 +686,7 @@ int32_t pRead( FS_t	    *fsMount,
 	off = xaddr << fsMount->l2bsize;
 	len = xlen << fsMount->l2bsize;
 	if ( (rc = ujfs_rw_diskblocks(LVHandle, off, len, p, GET)) ) {
-		message_user(MSG_OSO_READ_ERROR, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		message_user(MSG_OSO_READ_ERROR, NULL, 0, OSO_MSG);
 	}
 
 	return rc;
@@ -723,13 +709,13 @@ static void bAllocate(void)
 
 	/* allocate buffer header */
 	if ((bp = malloc(NBUFFER * sizeof(buf_t))) == NULL) {
-		message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, OSO_MSG);
 		exit (ERROR_DISK_FULL);
 	}
 
 	/* allocate buffer pages */
 	if ((buffer = malloc(NBUFFER * PAGESIZE)) == NULL) {
-		message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		message_user(MSG_OSO_NOT_ENOUGH_MEMORY, NULL, 0, OSO_MSG);
 		exit (ERROR_DISK_FULL);
 	}
 
@@ -771,7 +757,7 @@ int32_t bRead( FS_t	    *fsMount,
 	if (rc == 0)
 		*bpp = bp;
     else {
-		message_user(MSG_OSO_READ_ERROR, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		message_user(MSG_OSO_READ_ERROR, NULL, 0, OSO_MSG);
 		bRelease(bp);
 	}
 
@@ -797,7 +783,7 @@ int32_t bRawRead( uint32_t  LVHandle,
 	if (rc == 0)
 		*bpp = bp;
     else {
-		message_user(MSG_OSO_READ_ERROR, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		message_user(MSG_OSO_READ_ERROR, NULL, 0, OSO_MSG);
 		bRelease(bp);
 	}
 
@@ -810,7 +796,39 @@ void bRelease(buf_t	 *bp)
 	bp->b_next = bCachelist;
 	bCachelist = bp;
 }
+
+/*--------------------------------------------------------------------
+ * NAME: Is_Root_Mounted_RO
+ *
+ * FUNCTION: Determine if root is mounted read only
+ *
+ * RETURNS:
+ *      0 if root is not mounted READ ONLY
+ *    > 0 if root is mounted READ ONLY
+ *
+ * NOTES: borrowed some of this routine from e2fsck
+ */
+int Is_Root_Mounted_RO()
+{
+  int  fd, rc=0;
+
+  #define TEST_FILE "/.ismount-test-file"		
+  
+  fd = open(TEST_FILE, O_RDWR|O_CREAT);
+
+  if (fd < 0) {
+    if (errno == EROFS)
+      rc = MSG_JFS_VOLUME_IS_MOUNTED_RO;
+  } else {
+    close(fd);
+    (void) unlink(TEST_FILE);
+  }
+
+  return rc;
+}
+
  
+#if HAVE_MNTENT_H
 /*--------------------------------------------------------------------
  * NAME: Is_Device_Mounted
  *
@@ -916,38 +934,6 @@ int Is_Device_Mounted(char  *Device_Name)
   return Mounted_RC;
 }
 
-
-/*--------------------------------------------------------------------
- * NAME: Is_Root_Mounted_RO
- *
- * FUNCTION: Determine if root is mounted read only
- *
- * RETURNS:
- *      0 if root is not mounted READ ONLY
- *    > 0 if root is mounted READ ONLY
- *
- * NOTES: borrowed some of this routine from e2fsck
- */
-int Is_Root_Mounted_RO()
-{
-  int  fd, rc=0;
-
-  #define TEST_FILE "/.ismount-test-file"		
-  
-  fd = open(TEST_FILE, O_RDWR|O_CREAT);
-
-  if (fd < 0) {
-    if (errno == EROFS)
-      rc = MSG_JFS_VOLUME_IS_MOUNTED_RO;
-  } else {
-    close(fd);
-    (void) unlink(TEST_FILE);
-  }
-
-  return rc;
-}
-
-
 /*--------------------------------------------------------------------
  * NAME: Is_Device_Type_JFS
  *
@@ -996,3 +982,113 @@ int Is_Device_Type_JFS(char  *Device_Name)
   /* Return the appropriate value. */
   return Is_JFS_RC;
 }
+#endif /* HAVE_MNTENT_H */
+
+#if HAVE_GETMNTINFO
+/*--------------------------------------------------------------------
+ * NAME: Is_Device_Mounted
+ *
+ * FUNCTION: Determine if the device specified is mounted.
+ *
+ * PRE CONDITIONS: Device_Name must be the name of the device.
+ *
+ * POST CONDITIONS:
+ *
+ * PARAMETERS: Device_Name - The name of the device.
+ *
+ * RETURNS:
+ *      0 if the device is not mounted.
+ *    > 0 if the device is mounted or an error occurs.
+ *
+ * NOTES: borrowed some of this routine from e2fsck
+ */
+int Is_Device_Mounted(char *Device_Name)
+{
+	struct statfs *mp;
+	int len, n;
+	char *s1, *s2;
+
+	n = getmntinfo(&mp, MNT_NOWAIT);
+	if (!n)
+		return MSG_JFS_MNT_LIST_ERROR;
+
+	len = sizeof(_PATH_DEV) - 1;
+	s1 = Device_Name;
+	if (strncmp(_PATH_DEV, s1, len) == 0)
+		s1 += len;
+
+	while (--n >= 0) {
+		s2 = mp->f_mntfromname;
+		if (strncmp(_PATH_DEV, s2, len) == 0) {
+			s2 += len - 1;
+			*s2 = 'r';
+		}
+		if (strcmp(s1, s2) == 0 || strcmp(s1, &s2[1]) == 0) {
+			if (strcmp(mp->f_fstypename, "jfs") == 0) {
+				/* is mounted, is type jfs */
+				/* XXX check for read-only somehow */
+				return MSG_JFS_VOLUME_IS_MOUNTED;
+			} else {
+				/* is mounted, is not type jfs */
+				return MSG_JFS_NOT_JFS;
+			}
+		}
+		++mp;
+	}
+
+	return 0;
+}
+
+/*--------------------------------------------------------------------
+ * NAME: Is_Device_Type_JFS
+ *
+ * FUNCTION: Determine if the device specified is of type JFS in /etc/fstab
+ *
+ * PRE CONDITIONS: Device_Name must be the name of the device.
+ *
+ * POST CONDITIONS:
+ *
+ * PARAMETERS: Device_Name - The name of the device.
+ *
+ * RETURNS:
+ *      0 if the device is type JFS in /etc/fstab
+ *    > 0 if the device is not type JFS or an error occurs.
+ *
+ */
+int Is_Device_Type_JFS(char *Device_Name)
+{
+	struct statfs *mp;
+	int len, n;
+	char *s1, *s2;
+
+	n = getmntinfo(&mp, MNT_NOWAIT);
+	if (!n)
+		return MSG_JFS_MNT_LIST_ERROR;
+
+	len = sizeof(_PATH_DEV) - 1;
+	s1 = Device_Name;
+	if (strncmp(_PATH_DEV, s1, len) == 0)
+		s1 += len;
+
+	while (--n >= 0) {
+		s2 = mp->f_mntfromname;
+		if (strncmp(_PATH_DEV, s2, len) == 0) {
+			s2 += len - 1;
+			*s2 = 'r';
+		}
+		if (strcmp(s1, s2) == 0 || strcmp(s1, &s2[1]) == 0) {
+			if (strcmp(mp->f_fstypename, "jfs") == 0) {
+				/* is mounted, is type jfs */
+				/* XXX check for read-only somehow */
+				return 0;
+			} else {
+				/* is mounted, is not type jfs */
+				return MSG_JFS_NOT_JFS;
+			}
+		}
+		++mp;
+	}
+
+	return MSG_JFS_DEV_NOT_IN_TABLE;
+}
+#endif /* HAVE_GETMNTINFO */
