@@ -16,40 +16,13 @@ along with this program;  if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
-#include "jfs_types.h"
+#include "jfs_endian.h"
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
-#include "jfs_byteorder.h"
-#include "jfs_superblock.h"
-#include "jfs_dmap.h"
-#include "jfs_dinode.h"
-#include "jfs_logmgr.h"
-#include "fsckwsp.h"
 #include "devices.h"
 
-void ujfs_swap_dtpage_t( dtpage_t *, uint32_t );
-void ujfs_swap_xtpage_t( xtpage_t * );
-uint32_t type_jfs;
-
-/* taken from e2fsprogs */
-static int i386_byteorder(void)
-{
-	int   one = 1;
-	char  *cp = (char *) &one;
-
-	return (*cp == 1);
-}
-
-/* taken from e2fsprogs */
-int jfs_native_flag(void)
-{
-	if (i386_byteorder())
-		return 0;
-	return JFS_SWAP_BYTES;
-}
-
-
+#if __BYTE_ORDER == __BIG_ENDIAN
 /*--------------------------------------------------------------------
  * NAME: ujfs_swap_dbmap_t
  *
@@ -513,12 +486,6 @@ void ujfs_swap_logsuper_t( logsuper_t  *lsup_t )
     lsup_t->flag    = __le32_to_cpu(lsup_t->flag);  
     lsup_t->state   = __le32_to_cpu(lsup_t->state);  
     lsup_t->end     = __le32_to_cpu(lsup_t->end);  
-
-    for (i=0; i<8; i++)
-      lsup_t->active[i] = __le32_to_cpu(lsup_t->active[i]);  
-
-    for (i=0; i<LOGPSIZE / 4 - 17; i++)
-      lsup_t->rsrvd[i] = __le32_to_cpu(lsup_t->rsrvd[i]);  
 }
 
 
@@ -617,10 +584,6 @@ void ujfs_swap_superblock( struct superblock  *sblk )
     
     sblk->s_fsckloglen = __le32_to_cpu(sblk->s_fsckloglen);  
     sblk->s_xsize      = __le64_to_cpu(sblk->s_xsize);	
-
-    sblk->totalUsable = __le64_to_cpu(sblk->totalUsable);   
-    sblk->minFree     = __le64_to_cpu(sblk->minFree);	
-    sblk->realFree    = __le64_to_cpu(sblk->realFree);	
 }
 
 
@@ -648,3 +611,23 @@ void ujfs_swap_xtpage_t( xtpage_t  *xtp_t )
 
     xtp_t->header.nextindex = __le16_to_cpu(xtp_t->header.nextindex);      
 }
+
+/*--------------------------------------------------------------------
+ * NAME: ujfs_swap_fscklog_entry_hdr_t
+ *
+ * FUNCTION: Change endianness of fscklog_entry_hdr_t structure
+ *
+ * PARAMETERS:
+ *      hdptr         - pointer to fscklog_entry_hdr_t structure
+ *
+ * RETURNS: NONE
+ */
+void ujfs_swap_fscklog_entry_hdr_t( logent_hdptr hdptr )
+{
+    /* fscklog_entry_hdr_t in fscklog.h */
+
+    hdptr->entry_length = __le16_to_cpu(hdptr->entry_length);           
+    hdptr->msg_num      = __le16_to_cpu(hdptr->msg_num);
+    hdptr->num_parms    = __le16_to_cpu(hdptr->num_parms);       
+}
+#endif	/* BIG ENDIAN */
