@@ -32,7 +32,8 @@
 #include <stdlib.h>
 #include <memory.h>
 #include <string.h>
-#include "jfs_byteorder.h"
+#include <fcntl.h>
+#include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
 #include "jfs_dinode.h"
@@ -41,11 +42,12 @@
 #include "jfs_logmgr.h"
 #include "jfs_dmap.h"
 #include "jfs_imap.h"
-#include "jfs_debug.h"
 #include "logredo.h"
 #include "devices.h"
 #include "debug.h"
 
+extern int LogOpenMode;
+
 #define LOGDMP_OK 	0
 #define LOGDMP_FAILED	-1
 
@@ -75,13 +77,7 @@
  *
  *       things for the log.
  */
-extern int16_t  loglocation;   /* 1 = inlinelog, 2 = outlinelog */
-extern int32_t  logmajor;      /* major number of log device */
-extern int32_t  logminor;      /* minor number of log device */
-int32_t     logserial;         /* log serial number in super block */
 int32_t     logend;            /* address of the end of last log record */
-int32_t     logfd;             /* file descriptor for log */
-int32_t     logsize;           /* size of log in pages */
 logsuper_t  logsup;            /* log super block */
 int32_t     numdoblk;          /* number of do blocks used     */
 int32_t     numnodofile;       /* number of nodo file blocks used  */
@@ -120,7 +116,11 @@ int logdmp_outfile_is_open = 0;
  * by their minor number with the same major number,
  * the maximum number of lvs in a volume group is NUMMINOR (256).
  */
-struct vopen vopen[NUMMINOR];
+
+/*
+ * We only deal with the log here.  No need for vopen array
+ */
+struct vopen volume;
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
  *
@@ -168,8 +168,6 @@ int32_t  mntcnt, bufsize;
 char     *mntinfo;
 int32_t  retcode;                        /* return code from logredo    */
 
-char     loglockpath[MAXPATHLEN + 1];    /* log lock file               */
-
 /*
  * external references
  */
@@ -184,20 +182,15 @@ extern int32_t logredoInit(void);
 extern int32_t alloc_storage( int32_t, void **, int32_t * );
 
 extern int alloc_wrksp( uint32_t, int, int, void ** );    /* defined in fsckwsp.c */
-extern void ujfs_swap_superblock ( struct superblock * );
-extern void ujfs_swap_logsuper_t ( logsuper_t * );
 
 /*
  * forward references
  */
 int32_t open_outfile( void );
-int     ldmp_doMount( struct lrd * );
-int32_t ldmp_openVol( int32_t  );
-int32_t ldmp_rdwrSuper( int32_t ,   struct superblock *, int32_t );
+int32_t ldmp_readSuper( int32_t ,   struct superblock * );
 int     ldmp_isLogging( caddr_t , int32_t , char *, int32_t );
 int32_t ldmp_isFilesystem( caddr_t , int32_t );
 int32_t ldmp_logOpen(void);
-int     ldmp_fsError( int , int , int64_t );
 int     ldmp_logError( int , int );
 int     usage (void);
 
@@ -240,9 +233,10 @@ int32_t  jfs_logdump( caddr_t  pathname, int32_t  fd, int32_t  dump_all )
     bufsize = sizeof(int);
 
     /*
-     * validate that the log is not currently in use;
+     * Find and open the log
      */
-    rc = ldmp_isLogging(pathname, fd, mntinfo, mntcnt);
+    LogOpenMode = O_RDONLY;
+    rc = findLog(fd);
 
     if (rc < 0 ) {
       printf( "JFS_LOGDUMP:Error occurred when open/read device\n" );
@@ -252,20 +246,14 @@ int32_t  jfs_logdump( caddr_t  pathname, int32_t  fd, int32_t  dump_all )
       return(rc);
     }
 
-    /*
-     *      open log
-     */
-    logfd = ldmp_logOpen();
-
-
     /*
      * validate log superblock
      *
      * aggregate block size is for log file as well.
      */
 
-    rc = ujfs_rw_diskblocks( logfd,
-                             (uint64_t)(vopen[logminor].logxaddr+LOGPNTOB(LOGSUPER_B)),
+    rc = ujfs_rw_diskblocks( log.fd,
+                             (uint64_t)(log.xaddr+LOGPNTOB(LOGSUPER_B)),
                              (unsigned)sizeof(logsuper_t),
                              (char *)&logsup,
                              GET);
@@ -317,8 +305,8 @@ int32_t  jfs_logdump( caddr_t  pathname, int32_t  fd, int32_t  dump_all )
       fprintf(outfp, "\n");
     }
 
-    logsize = logsup.size;
-    logserial = logsup.serial;
+    log.size = logsup.size;
+    log.serial = logsup.serial;
 
     /*
      * find the end of log
@@ -328,8 +316,8 @@ int32_t  jfs_logdump( caddr_t  pathname, int32_t  fd, int32_t  dump_all )
       printf("logend < 0\n");
       ldmp_logError(LOGEND,0);
       ujfs_swap_logsuper_t ( &logsup );
-      rc = ujfs_rw_diskblocks(logfd,
-                              (uint64_t)(vopen[logminor].logxaddr+LOGPNTOB(LOGSUPER_B)),
+      rc = ujfs_rw_diskblocks(log.fd,
+                              (uint64_t)(log.xaddr+LOGPNTOB(LOGSUPER_B)),
                               (unsigned long)LOGPSIZE,
                               (char *)&logsup,
                               PUT);
@@ -540,157 +528,16 @@ int32_t  jfs_logdump( caddr_t  pathname, int32_t  fd, int32_t  dump_all )
 
 /*----------------------------------------------------------------
  *
- * NAME:        ldmp_doMount(ld)
+ * NAME:        ldmp_readSuper(fd, sb)
  *
- * FUNCTION:    a log mount record is the first-in-time record which is
- *              put in the log so it is the last we want to process in
- *              logredo. so we mark volume as cleanly unmounted in vopen
- *              array. the mount record is imperative when the volume
- *              is a newly made filesystem.
- */
-int ldmp_doMount(struct lrd  *ld)        /* pointer to record descriptor */
-{
-  int  vol, status;
-
-  vol = 0;
-  status = vopen[vol].status;
-
-  if (status != FM_LOGREDO && status != FM_DIRTY)
-    vopen[vol].status = FM_CLEAN;
-
-  return(0);
-}
-
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_openVol(vol)
- *
- * FUNCTION:    open the aggregate/volume specified.
- *              check if it was cleanly unmounted. also check log
- *              serial number. initialize disk and inode mpas.
- */
-int32_t ldmp_openVol(int32_t  vol)    /* device minor number of aggregate/lv */
-{
-  int32_t  fd, rc, l2agsize, agsize;
-  int64_t  fssize; /* number of aggre. blks in the aggregate/lv   */
-  struct superblock  sb;
-
-  fd = vopen[logminor].fd;
-
-  /* read superblock of the aggregate/volume */
-  if ((rc = ldmp_rdwrSuper(fd, &sb, PB_READ)) !=0) {
-    printf( "ldmp_openVol: ldmp_rdwrSuper failed\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    fprintf(outfp, "ldmp_openVol: ldmp_rdwrSuper failed\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    ldmp_fsError(READERR,vol, SUPER1_B);
-    vopen[vol].active = 0;
-    return(MINOR_ERROR);
-  }
-
-  /* check magic number and initialize version specific
-   * values in the vopen struct for this vol.
-   */
-  if (strncmp(sb.s_magic,JFS_MAGIC,(unsigned)strlen(JFS_MAGIC)) == 0) {
-    if (sb.s_version != JFS_VERSION) {
-      printf( "ldmp_openVol:version number not right %d\n",vol );
-      fprintf(outfp, "??????????????????????????????????????????????????????\n");
-      fprintf(outfp, "ldmp_openVol:version number not right %d\n",vol );
-      fprintf(outfp, "??????????????????????????????????????????????????????\n");
-      vopen[vol].active = 0;
-      return(MINOR_ERROR);
-    }
-
-    if ( loglocation == OUTLINELOG &&
-         (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG) )) {
-      printf( "ldmp_openVol: log location wrong\n" );
-      fprintf(outfp, "??????????????????????????????????????????????????????\n");
-      fprintf(outfp, "ldmp_openVol: log location wrong\n" );
-      fprintf(outfp, "??????????????????????????????????????????????????????\n");
-      vopen[vol].active = 0;
-      return(MAJOR_ERROR);
-    }
-    if ( loglocation != INLINELOG) {
-      return(MAJOR_ERROR);
-    }
-    vopen[vol].lblksize = sb.s_bsize;
-    vopen[vol].l2bsize = sb.s_l2bsize;
-    vopen[vol].l2bfactor = sb.s_l2bfactor;
-    fssize = sb.s_size >> sb.s_l2bfactor;
-    vopen[vol].fssize = fssize;
-    vopen[vol].agsize = sb.s_agsize;
-    /* LOG2NUM will alter agsize, so use local var */
-    agsize = vopen[vol].agsize;
-    LOG2NUM(agsize, l2agsize);
-    vopen[vol].numag = fssize >> l2agsize;
-    if ( fssize & (vopen[vol].agsize - 1 ))
-      vopen[vol].numag += 1;
-    vopen[vol].l2agsize = l2agsize;
-  } else {
-    printf( "ldmp_openVol: magic number not right %d\n",vol );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    fprintf(outfp, "ldmp_openVol: magic number not right %d\n",vol );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    vopen[vol].active = 0;
-    return(MINOR_ERROR);
-  }
-
-  /* set lbperpage in vopen.
-   */
-  vopen[vol].lbperpage = PSIZE >> vopen[vol].l2bsize;
-
-  /* was it cleanly umounted ?
-   */
-  if (sb.s_state == FM_CLEAN) {
-    vopen[vol].status  = FM_CLEAN;
-    vopen[vol].active = 0;
-    return(0);
-  }
-
-  /* else get status of volume
-   */
-  vopen[vol].status = sb.s_state;
-  vopen[vol].is_fsdirty = ( sb.s_state == FM_DIRTY );
-
-  /* check log serial number
-   */
-  if (sb.s_logserial != logserial) {
-    printf( "ldmp_openVol: bad serial number\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    fprintf(outfp, "ldmp_openVol: bad serial number\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    vopen[vol].active = 0;
-    ldmp_fsError(SERIALNO, vol, SUPER1_B);
-    return(MINOR_ERROR);
-  }
-
-  /* initialize the disk and inode maps
-   */
-  if ((rc = initMaps(vol)) !=0) {
-    printf( "ldmp_openVol: initMaps failed\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    fprintf(outfp, "ldmp_openVol: initMaps failed\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    ldmp_fsError(MAPERR,vol,0);
-  }
-  return(rc);
-}
-
-
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_rdwrSuper(fd, sb, rwflag)
- *
- * FUNCTION:    read or write the superblock for the file system described
+ * FUNCTION:    read the superblock for the file system described
  *              by the file descriptor of the opened aggregate/lv.
- *              for read, if a read of primary superblock is failed,
+ *              if a read of primary superblock fails,
  *              try to read the secondary superblock. report error only
  *              when both reads failed.
- *              for write, any write failure should be reported.
  */
-int32_t ldmp_rdwrSuper( int32_t            fd,  /* file descriptor */
-                        struct superblock  *sb, /* superblock of the opened aggregate/lv */
-                        int32_t            rwflag )  /* PB_READ, PB_UPDATE   */
+int32_t ldmp_readSuper( int32_t            fd,  /* file descriptor */
+                        struct superblock  *sb) /* superblock of the opened aggregate/lv */
 {
   int32_t  rc;
 
@@ -709,14 +556,13 @@ int32_t ldmp_rdwrSuper( int32_t            fd,  /* file descriptor */
   /*
    * read super block
    */
-  if (rwflag == PB_READ) {
     rc = ujfs_rw_diskblocks(fd, SUPER1_OFF,
                             (unsigned)SIZE_OF_SUPER,
                             super.block, GET);
     if ( rc != 0 ) {
-      printf( "ldmp_rdwrSuper: read primary agg superblock failed. errno=%d  Continuing.\n", errno );
+      printf( "ldmp_readSuper: read primary agg superblock failed. errno=%d  Continuing.\n", errno );
       fprintf(outfp, "??????????????????????????????????????????????????????\n");
-      fprintf(outfp, "ldmp_rdwrSuper: read primary agg superblock failed. errno=%d Continuing\n", errno );
+      fprintf(outfp, "ldmp_readSuper: read primary agg superblock failed. errno=%d Continuing\n", errno );
       fprintf(outfp, "??????????????????????????????????????????????????????\n");
       /* read failed for the primary superblock:
        * try to read the secondary superblock
@@ -725,9 +571,9 @@ int32_t ldmp_rdwrSuper( int32_t            fd,  /* file descriptor */
                               (unsigned)SIZE_OF_SUPER,
                               super.block, GET);
       if ( rc != 0 ) {
-        printf( "ldmp_rdwrSuper: read 2ndary agg superblock failed. errno=%d  Cannot continue.\n", errno );
+        printf( "ldmp_readSuper: read 2ndary agg superblock failed. errno=%d  Cannot continue.\n", errno );
         fprintf(outfp, "??????????????????????????????????????????????????????\n");
-        fprintf(outfp, "ldmp_rdwrSuper: read 2ndary agg superblock failed. errno=%d  Cannot continue.\n", errno );
+        fprintf(outfp, "ldmp_readSuper: read 2ndary agg superblock failed. errno=%d  Cannot continue.\n", errno );
         fprintf(outfp, "??????????????????????????????????????????????????????\n");
         return(MAJOR_ERROR);
       }
@@ -737,248 +583,12 @@ int32_t ldmp_rdwrSuper( int32_t            fd,  /* file descriptor */
 
     ujfs_swap_superblock( sb );
 
-  } else {
-    printf( "ldmp_rdwrSuper: log_dump attempting to write!!!\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    fprintf(outfp, "ldmp_rdwrSuper: log_dump attempting to write!!!\n" );
-    fprintf(outfp, "??????????????????????????????????????????????????????\n");
-    return(MAJOR_ERROR);
-  }
-
   return(0);
 }
 
 
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_isLogging()
- *
- * FUNCTION:    Check to see if device is currently in use as a log
- *
- * NOTES: mntctl and stat are AIX system calls.  major and minor number are
- *        also AIX concept. 
- *
- * DATA STRUCTURES: global variables logmajor and logminor are altered.
- *
- * PARAMETERS:  logname - device name
- *              fd      - file handle for the logname
- *              vmt     - pointer to buffer that contains an array of
- *                        vmount sturctures, which are returned by the
- *                        mntctl system call.
- *              cnt     - number of vmount structures in buffer pointed by vmt
- *
- * RETURNS:     0       - device logname is not actively used as a log
- *              NOT_FSDEV_ERROR (-6) Not a valid fs device (from ldmp_isFilesystem)
- *              NOT_INLINELOG_ERROR (-7) Log is not an inline log  (from ldmp_isFilesystem)
- *              MAJOR_ERROR - returned from ldmp_isFilesystem().
- *              MINOR_ERROR - devices already mounted that are using logname
- */
-int ldmp_isLogging( caddr_t  logname,
-                    int32_t  fd, 
-                    char     *vmt_in,
-                    int32_t  cnt)
-{
-  int32_t  rc = 0;
-
-  /*
-   * determine if logname represents a file system device  or
-   * a log device and set its major number
-   */
-  if ((rc = ldmp_isFilesystem(logname, fd)) < 0)
-    return(rc);
-
-  return(rc);
-}
-
-
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_isFilesystem()
- *
- * FUNCTION:     open the device to see if it's a valid filesystem.
- *               If open failed, then return MAJOR_ERROR.
- *               If open ok, and it is a valid file system,
- *               return the minor device number of the log for this
- *               filesystem. Otherwise, return MINOR_ERROR.
- *
- * PRE CONDITION: other process opened the device log should allow
- *                a O_RDONLY re-open.
- *
- * POST CONDITION: this O_RDONLY open is closed.
- *
- * PARAMETERS:  dev_name        - device name. This is the name passed to
- *                                logredo.
- *
- * RETURNS:
- *              NOT_FSDEV_ERROR (-6) Not a valid fs device
- *              NOT_INLINELOG_ERROR (-7) Log is not an inline log -
- *              MAJOR_ERROR(-2) -  open device  or stat device failure, or
- *                                 s_logdev number wrong.
- *                                 if it is not an inlinelog, it is
- *                                 an error.
- *              0               -  1)read fs superblock ok but dev_name does not
- *                                   represent a file system device name
- *                                 2)read fs fs superblock ok, dev_name
- *                                   represents a fs device name.
- *                                   loglocation is set up. ( INLINELOG or
- *                                   OUTLINELOG ).
- *                                 3)read fs superblock failed, but successful
- *                                   to read the device as log
- */
-int32_t ldmp_isFilesystem( caddr_t  dev_name,
-                           int32_t  fd  )
-{
-  int32_t  rc = 0;
-  struct superblock  sb;
-  int32_t  devmajor = 0;
-  int32_t  devminor = 0;
-
-  /*
-   * each file system must maintain its own in-line log.
-   */
-
-  /*
-   * try the LV as file system with in-line log
-   */
-  if ((rc = ldmp_rdwrSuper(fd, &sb, PB_READ)) == 0) {
-    /*
-     * is the LV a file system ?
-     */
-    if (strncmp(sb.s_magic,JFS_MAGIC,(unsigned)strlen(JFS_MAGIC))
-        == 0 ) {
-      /*
-       * does file system contains its in-line log ?
-       */
-      if ( ( sb.s_flag & JFS_INLINELOG ) == JFS_INLINELOG ) {
-        if ( !( logmajor == devmajor &&
-                logminor == devminor ) ) {
-          printf( "ldmp_isFilesystem: s_logdev is not a fs dev number\n" );
-          fprintf(outfp, "??????????????????????????????????????????????????????\n");
-          fprintf(outfp, "ldmp_isFilesystem: s_logdev is not a fs dev number\n" );
-          fprintf(outfp, "??????????????????????????????????????????????????????\n");
-          return(NOT_FSDEV_ERROR);
-        }
-
-        loglocation = INLINELOG;
-        vopen[devminor].active = 1;
-        vopen[devminor].fd = fd;
-        vopen[devminor].log_pxd = sb.s_logpxd;
-        vopen[devminor].l2bsize = sb.s_l2bsize;
-        vopen[devminor].logxaddr =
-        addressPXD(&sb.s_logpxd) << sb.s_l2bsize;
-
-      /*
-       * the FS is associated with external/out-of-line log
-       */
-      } else {
-        rc = NOT_INLINELOG_ERROR;
-      }
-
-    /*
-     * validation failure: the LV is not a file system:
-     */
-    } else {
-      rc = NOT_FSDEV_ERROR;
-    }
-
-  /*
-   * read failure: try the LV as out-of-line log
-   */
-  } else {
-    rc = NOT_INLINELOG_ERROR;
-  }
-  return(rc);
-}
-
-
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_logOpen()
- *
- * FUNCTION:    opens the log and returns its fd.
- *              sets logmajor to the major number of the device.
- *
- * PRE CONDITION: logmajor and logminor have been set up
- *
- * POST CONDITION: log is opened and locked by the loglock file
- *
- * PARAMETERS: NONE
- *
- * RETURNS:     >= 0    - file descriptor reported from makeOpen()
- *              < 0     - any error reported from makeOpen()
- */
-int32_t ldmp_logOpen()
-{
-  int  fd;
-
-  fd = vopen[logminor].fd;
-
-  return(fd);
-}
-
-
 extern void exit(int);
 
-/*----------------------------------------------------------------
- *
- * NAME:        ldmp_fsError(type,vol,bn)
- *
- * FUNCTION:    error handling code for the specified
- *              aggregate/lv (filesystem).
- */
-int ldmp_fsError( int      type,  /* error types */
-                  int      vol,   /* the minor number of the aggregate/lv */
-                  int64_t  bn)    /* aggregate block No.  */
-{
-
-  printf( "ldmp_fsError:bad error in volume %d \n", vol );
-  fprintf(outfp, "??????????????????????????????????????????????????????\n");
-  fprintf(outfp, "ldmp_fsError:bad error in volume %d \n", vol );
-
-  retcode = -1;
-  vopen[vol].status = FM_LOGREDO;
-
-  switch (type) {
-    case OPENERR:
-      printf( "Open failed \n" );
-      fprintf(outfp, "Open failed \n" );
-      break;
-    case MAPERR:
-      printf( "can not initialize maps \n" );
-      fprintf(outfp, "can not initialize maps \n" );
-      break;
-    case DBTYPE:
-      printf( "bad disk block number %lld\n", (long long)bn );
-      fprintf(outfp, "bad disk block number %lld\n", (long long)bn );
-      break;
-    case INOTYPE:
-      printf( "bad inode number %lld\n", (long long)bn );
-      fprintf(outfp, "bad inode number %lld\n", (long long)bn );
-      break;
-    case READERR:
-      printf( "can not read block number %lld\n", (long long)bn );
-      fprintf(outfp, "can not read block number %lld\n", (long long)bn );
-      break;
-    case SERIALNO:
-      printf( "log serial number no good /n" );
-      fprintf(outfp, "log serial number no good /n" );
-      break;
-    case IOERROR:
-      printf( "io error reading block number %lld\n", (long long)bn );
-      fprintf(outfp, "io error reading block number %lld\n", (long long)bn );
-      break;
-    case LOGRCERR:
-      printf( "UpdateMap log rec error. nxd=%lld\n", (long long)bn );
-      fprintf(outfp, "UpdateMap log rec error. nxd=%lld\n", (long long)bn );
-      break;
-  }
-
-  fprintf(outfp, "??????????????????????????????????????????????????????\n");
-
-  return(0);
-}
-
-
 /*----------------------------------------------------------------
  *
  *      ldmp_logError(type)
@@ -1026,13 +636,6 @@ int ldmp_logError( int  type,
   }
 
 
-  /* mark all open volumes in error
-   */
-  for (k = 0; k < NUMMINOR; k++) {
-    if (vopen[k].active && vopen[k].status != FM_CLEAN)
-      vopen[k].status = FM_LOGREDO;
-  }
-
   return(0);
 }
 /*----------------------------------------------------------------
