@@ -1,6 +1,4 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
- *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or 
@@ -16,5 +14,11 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
+#ifndef H_LOGFORM
+#define H_LOGFORM
 
-int32_t jfs_logform( int32_t, int32_t, int32_t, uint32_t, int64_t, int32_t, char*, int32_t);
+#include <uuid/uuid.h>
+
+int jfs_logform(int, int, int, uint, int64_t, int, uuid_t);
+
+#endif				/* H_LORFORM */
