@@ -29,13 +29,11 @@ char  Current_String[MAX_STRING_ACCEPTED + 1];
  *
  *  This function is
  *
- *  message_user (mesg_no, param, param_cnt, device, response, msg_file)
+ *  message_user (mesg_no, param, param_cnt, msg_file)
  *
  *  ENTRY    mesg_no   - index into the array of messages
  *           param     - list of pointers to parameters in the message
  *           param_cnt - count of parameters in the param variable
- *           device    - where to write to (STDOUT, STDERR)
- *           response  - what kind of response is needed from user
  *           msg_file  - OSO_MSG/JFS_MSG which message file to use
  *
  *  EXIT     Returns pointer to buffer contain the user's response
@@ -44,23 +42,16 @@ char  Current_String[MAX_STRING_ACCEPTED + 1];
  *  CALLS
  */
 
-char *message_user(unsigned mesg_no,
-                   char  **param,
-                   unsigned param_cnt,
-                   unsigned device,
-                   unsigned response,
-                   int      msg_file)
+void message_user(unsigned mesg_no, char **param,
+		  unsigned param_cnt, int msg_file)
 {
-
-  int  Current_Character;
-
   if ( msg_file == OSO_MSG ) {
       switch ( mesg_no ) {
           case  MSG_OSO_NOT_ENOUGH_MEMORY :
               printf("There is not enough memory available to process this command.\n");
               break;
           case  MSG_OSO_CANT_FIND_DRIVE :
-              printf("The system cannot find the specified device.\n");
+              printf("\nThe system cannot find the specified device.\n");
               break;
           case  MSG_OSO_CANT_OPEN :
               printf("The system cannot open the device or file specified.\n");
@@ -68,12 +59,6 @@ char *message_user(unsigned mesg_no,
           case  MSG_OSO_ERR_ACCESSING_DISK :
               printf(" An error occurred when accessing the hard disk.\n");
               break;
-          case  MSG_OSO_VALUE_REQUIRED :
-              printf("A value is required for %s.\n",param[0]);
-              break;
-          case  MSG_OSO_INVALID_PARAMETER :
-              printf(" %s is not a valid parameter to use with the mkfs.jfs command when formatting a hard disk.\n",param[0]);
-              break;
           case  MSG_OSO_DISK_LOCKED :
               printf(" The specified disk is being used by another process.\n");
               break;
@@ -86,18 +71,9 @@ char *message_user(unsigned mesg_no,
           case  MSG_OSO_INSUFF_MEMORY :
               printf("Not enough memory is available to run mkfs.jfs.\n");
               break;
-          case  MSG_OSO_CURR_LABEL :
-              printf("Type the current volume label for drive %s.\n",param[0]);
-              break;
-          case  MSG_OSO_BAD_LABEL :
-              printf("An incorrect volume label was entered for this drive.\n");
-              break;
           case  MSG_OSO_DESTROY_DATA :
               printf("Warning!  All data on device %s will be lost!\n",param[0]);
               break;
-          case  MSG_OSO_NEW_LABEL :
-              printf("Enter up to 11 characters for the volume label:");
-              break;
           case  MSG_OSO_FORMAT_COMPLETE :
               printf("\n\nFormat completed successfully.\n\n");
               break;
@@ -119,11 +95,6 @@ char *message_user(unsigned mesg_no,
           case MSG_OSO_NOT_VALID_BLOCK_DEVICE:
               printf("%s is not a valid block device.\n",param[0]);
               break;
-          case MSG_OSO_MKFS_USAGE:
-              printf("\nUsage:  mkfs.jfs [-c] [-L volume-label] [-O] [-q] [-s log-size] [-V] <device>\n");
-              printf("See man(8) mkfs.jfs for more information\n");
-              break;
-
           default:  /* Error!  Unknown message number! */
               break;
       }
@@ -137,12 +108,6 @@ char *message_user(unsigned mesg_no,
           case  MSG_JFS_LOG_LARGE :
               printf("Log too large, no space for file system.\n");
               break;
-          case  MSG_JFS_LT16MEG_ADAPTER :
-              printf("Adapter cannot access physical memory above 16 Megabytes.\n");
-              break;
-          case  MSG_JFS_VOL_NOT_LVM :
-              printf("Only an LVM partition can be formatted as a JFS file system.\n");
-              break;
           case  MSG_JFS_BAD_PART :
               /* This message is basically from ext2 */
               printf("Device size reported to be zero.  Invalid partition specified, or\n"
@@ -274,7 +239,6 @@ char *message_user(unsigned mesg_no,
               break;
           case 166:
               printf("Usage:  fsck.jfs [-a] [-f] [-n] [-o] [-p] [-v] [-V] <device>\n");
-              printf("See man(8) fsck.jfs for more information\n");
               break;
           case 167:
               printf("Unrecognized -f parameter value detected:   %s\n", param[0]);
@@ -451,7 +415,7 @@ char *message_user(unsigned mesg_no,
               printf("Phase 8 - Verify Disk Allocation Maps.\n");
               break;
           case 335 :
-              printf("The file system type for %s is not listed as jfs \nin the file system description file /etc/fstab.\n\n",param[0]);
+              printf("NOTE: The file system type for %s is not listed \nas jfs in the file system description file /etc/fstab.\n\n",param[0]);
               break;
           case 343:
               printf("Unable to read the secondary File/Directory Allocation Table.\n");
@@ -593,88 +557,4 @@ char *message_user(unsigned mesg_no,
       }
 
   }
-
-  /* Now that the message has been displayed, lets see what to do about a response. */
-  switch ( response ) {
-      case  NO_RESPONSE : /* no response is necessary */
-          break;
-      case  CR_RESPONSE : /* press Enter key, input is eaten */
-          do {
-            printf("\nPress enter to continue.\n");
-            Current_Character = getchar();
-          } while ( ( Current_Character != '\n' ) &&
-                    ( Current_Character != EOF )     );
-          break;
-      case  YES_NO_RESPONSE : /* "y" or "n" only -- value returned */
-          do {
-            printf("\nContinue? (Y/N) ");
-            Current_Character = getchar();
-          } while ( ( Current_Character != 'y' ) &&
-                    ( Current_Character != 'Y' ) &&
-                    ( Current_Character != 'N' ) &&
-                    ( Current_Character != 'n' ) &&
-                    ( Current_Character != EOF )    );
-          switch ( Current_Character ) {
-              case 'Y' :
-              case 'y' :
-                  return "Y";
-                  break;
-              case 'N' :
-              case 'n' :
-                  return "N";
-                  break;
-              default:
-                  /* Abort program. */
-                  abort();
-                  break;
-          }
-
-          break;
-      case  STRING_RESPONSE : /*  string value returned */
-          if ( fgets(Current_String,MAX_STRING_ACCEPTED,stdin) )
-            return Current_String;
-          break;
-      case  ANY_KEY_RESPONSE : /* press Any key, input is eaten */
-          printf("\nPress any key to continue.\n");
-          Current_Character = getchar();
-          break;
-      case  ARI_RESPONSE : /* Abort, Retry, Ignore */
-          do {
-            printf("\nAbort, Retry, or Ignore? \n");
-            Current_Character = getchar();
-          } while ( ( Current_Character != 'A' ) &&
-                    ( Current_Character != 'a' ) &&
-                    ( Current_Character != 'R' ) &&
-                    ( Current_Character != 'r' ) &&
-                    ( Current_Character != 'I' ) &&
-                    ( Current_Character != 'i' ) &&
-                    ( Current_Character != EOF )    );
-          switch ( Current_Character ) {
-              case 'A' :
-              case 'a' :
-                  return "A";
-                  break;
-              case 'R' :
-              case 'r' :
-                  return "R";
-                  break;
-              case 'I' :
-              case 'i' :
-                  return "I";
-                  break;
-              default:
-                  /* Abort program. */
-                  abort();
-                  break;
-          }
-
-          break;
-      default: /* Error!  Unrecognized response code! */
-          printf("\nInternal error!  Unrecognized response code passed to message_user!\n");
-          abort();
-          break;
-  }
-
-  return NULL;
-
 }
