@@ -22,9 +22,6 @@
 
 int32_t ujfs_validate_super(struct superblock *);
 int32_t ujfs_put_superblk(HFILE, struct superblock *, int16_t);
-int32_t ujfs_init_superblock(struct superblock *, HFILE, char *, int64_t, uint32_t,
-		int32_t, int32_t, uint32_t, int64_t, int32_t, int32_t, int64_t, int32_t, int32_t,
-		int64_t, int32_t, int64_t, int32_t );
 int32_t ujfs_get_superblk(HFILE, struct superblock *, int32_t);
 int32_t inrange(uint32_t, uint32_t, uint32_t);
 
