@@ -48,7 +48,7 @@
 #include <string.h>
 #include <time.h>
 #include <errno.h>
-#include "jfs_byteorder.h"
+#include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_dinode.h"
 #include "devices.h"
@@ -60,6 +60,8 @@
 #include "message.h"
 #include "utilsubs.h"
 
+extern uint32_t type_jfs;
+
 #define UZWORD  (0x80000000u)
 #define DBBYTE          8       /* number of bits per byte */
 #define L2DBBYTE        3       /* log2 of number of bits per byte */
@@ -84,14 +86,6 @@ static xtree_buf_t  *badblock_pages;
 static int32_t xtAppend( HFILE, struct dinode *, int64_t, 
                          int64_t, int32_t, xtree_buf_t *, int32_t );
 
-/* endian routines */
-extern uint32_t type_jfs;
-extern void ujfs_swap_dmapctl_t( dmapctl_t  * );
-extern void ujfs_swap_xtpage_t( xtpage_t  * );
-extern void ujfs_swap_dbmap_t( dbmap_t  * );
-extern void ujfs_swap_dmap_t( dmap_t  * );
-
-
 /*--------------------------------------------------------------------
  * NAME:        initdmap()
  *
@@ -134,7 +128,7 @@ static int32_t initdmap( int32_t  dev_ptr,
             if ( empty_page == NULL ) {
                 empty_page = malloc( sizeof( dmap_t ) );
                 if ( empty_page == NULL ) {
-                    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+                    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
                     return( ENOMEM );
                 }
                 memset( empty_page, 0, sizeof( dmap_t ) );
@@ -154,7 +148,7 @@ static int32_t initdmap( int32_t  dev_ptr,
              */
             block_map_array[cur_dmap_index] = malloc( sizeof( dmap_t ) );
             if ( block_map_array[cur_dmap_index] == NULL ) {
-                message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+                message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
                 return( ENOMEM );
             }
             memset( block_map_array[cur_dmap_index], 0, sizeof( dmap_t ) );
@@ -173,24 +167,10 @@ static int32_t initdmap( int32_t  dev_ptr,
      */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        /* copy to buffer for swap */
-        dmap_t  *buffer;
-        buffer = malloc(sizeof(dmap_t));
-        if ( buffer == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-            return( ENOMEM );
-        }
-        memcpy( buffer, block_map_array[cur_dmap_index], sizeof(dmap_t));
-        ujfs_swap_dmap_t( buffer );
-
-        rc = ujfs_rw_diskblocks( dev_ptr, start, PSIZE, buffer, PUT );
-
-        free( buffer );
-    } else {
-        rc = ujfs_rw_diskblocks( dev_ptr, start, PSIZE,
-                                 block_map_array[cur_dmap_index], PUT );
-    }
+    ujfs_swap_dmap_t(block_map_array[cur_dmap_index]);
+    rc = ujfs_rw_diskblocks( dev_ptr, start, PSIZE,
+                             block_map_array[cur_dmap_index], PUT );
+    ujfs_swap_dmap_t(block_map_array[cur_dmap_index]);
 
     if ( rc != 0 ) return rc;
 
@@ -253,7 +233,7 @@ static int32_t initctl( int32_t  dev_ptr,
      */
     dcp = malloc( sizeof(dmapctl_t) );
     if ( dcp == NULL ) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return( ENOMEM );
     }
     memset( dcp, 0, sizeof(dmapctl_t) );
@@ -317,9 +297,7 @@ static int32_t initctl( int32_t  dev_ptr,
      */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmapctl_t( dcp );
-    }
+    ujfs_swap_dmapctl_t( dcp );
 
     rc += ujfs_rw_diskblocks( dev_ptr, *start, PSIZE, dcp, PUT);
 
@@ -380,23 +358,9 @@ static int32_t initbmap( int32_t  dev_ptr,
      */
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        /* copy to buffer for swap */
-        dbmap_t  *buffer;
-        buffer = malloc(sizeof(dbmap_t));
-        if ( buffer == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-            return( ENOMEM );
-        }
-        memcpy( buffer, control_page, sizeof(dbmap_t));
-        ujfs_swap_dbmap_t( buffer );
-
-        rc = ujfs_rw_diskblocks( dev_ptr, BMAP_OFF, PSIZE, buffer, PUT );
-
-        free( buffer );
-    } else {
-        rc = ujfs_rw_diskblocks( dev_ptr, BMAP_OFF, PSIZE, control_page, PUT );
-    }
+    ujfs_swap_dbmap_t(control_page);
+    rc = ujfs_rw_diskblocks( dev_ptr, BMAP_OFF, PSIZE, control_page, PUT );
+    ujfs_swap_dbmap_t(control_page);
 
     return( rc );
 }
@@ -423,7 +387,7 @@ static int32_t alloc_map( int32_t  num_dmaps )
     /* alloc/init dmap page pointer array */
     block_map_array = malloc( num_dmaps * sizeof( dmap_t * ) );
     if ( block_map_array == NULL ) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return ENOMEM;
     }
     sz_block_map_array = num_dmaps;
@@ -433,7 +397,7 @@ static int32_t alloc_map( int32_t  num_dmaps )
     /* alloc/init control page */
     control_page = malloc( sizeof( dbmap_t ) );
     if ( control_page == NULL ) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return ENOMEM;
     }
 
@@ -650,7 +614,7 @@ int32_t markit( int32_t   block,
         nb = MIN( BPERDMAP, num_blocks_left );
         block_map_array[page] = malloc( sizeof( dmap_t ) );
         if ( block_map_array[page] == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
             return( ENOMEM );
         }
         memset( block_map_array[page], 0, sizeof( dmap_t ) );
@@ -872,7 +836,7 @@ static int32_t xtSplitRoot( HFILE          dev_ptr,
     /* Allocate and initialize buffer for new page to accomodate the split */
     newbuf = malloc(sizeof(xtree_buf_t));
     if ( newbuf == NULL) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return( ENOMEM );
     }
     newbuf->up = xroot;
@@ -885,7 +849,7 @@ static int32_t xtSplitRoot( HFILE          dev_ptr,
     xroot->down = newbuf;
     newpage = newbuf->page = malloc(PSIZE);
     if ( newpage == NULL) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return( ENOMEM );
     }
 
@@ -987,21 +951,9 @@ static int32_t xtSplitPage( struct dinode  *ip,
     leftbn = addressPXD(&(lastpage->header.self));
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        /* copy to buffer for swap */
-        xtpage_t  *buffer;
-        buffer = malloc(sizeof(xtpage_t));
-        if ( buffer == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-            return( ENOMEM );
-        }
-        memcpy( buffer, lastpage, sizeof(xtpage_t));
-        ujfs_swap_xtpage_t( buffer );
-        rc = ujfs_rw_diskblocks(dev_ptr, leftbn * aggr_block_size, PSIZE, buffer, PUT);
-        free( buffer );
-    } else {
-        rc = ujfs_rw_diskblocks(dev_ptr, leftbn * aggr_block_size, PSIZE, lastpage, PUT);
-    }
+    ujfs_swap_xtpage_t(lastpage);
+    rc = ujfs_rw_diskblocks(dev_ptr, leftbn * aggr_block_size, PSIZE, lastpage, PUT);
+    ujfs_swap_xtpage_t(lastpage);
 
     if ( rc != 0) return rc;
 
@@ -1188,7 +1140,7 @@ int32_t verify_last_blocks( int32_t        dev_ptr,
          */
         badblock_pages = malloc(sizeof(xtree_buf_t));
         if ( badblock_pages == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
             return( ENOMEM );
         }
         badblock_pages->down = badblock_pages->up = NULL;
@@ -1201,7 +1153,7 @@ int32_t verify_last_blocks( int32_t        dev_ptr,
         bufsize >>= 1;
 
     if ( buffer == NULL ) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return( ENOMEM );
     }
     nbufblks = bufsize / aggr_block_size;
@@ -1218,7 +1170,7 @@ int32_t verify_last_blocks( int32_t        dev_ptr,
             percent = blkno * 100 / control_page->dn_mapsize;
             sprintf(msgstr, "%d", percent);
             msg_parms[0] = msgstr;
-            message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, OSO_MSG);
             fprintf(stdout,"\r");
             fflush(stdout);
             index = 0;
@@ -1288,7 +1240,7 @@ int32_t verify_last_blocks( int32_t        dev_ptr,
         }
     }
     msg_parms[0] = "100";
-    message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+    message_user(MSG_OSO_PERCENT_FORMAT, msg_parms, 1, OSO_MSG);
     fprintf(stdout, "\n");
 
     free( buffer );
@@ -1297,36 +1249,20 @@ int32_t verify_last_blocks( int32_t        dev_ptr,
         /* We added bad blocks, flush pages to disk */
         curpage = badblock_pages;
 
-        /* swap if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) {
-            buffer = malloc(sizeof(xtpage_t));
-            if ( buffer == NULL) {
-                message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-                return( ENOMEM );
-            }
-        }
-
         while ( !(curpage->page->header.flag & BT_ROOT) ) {
             blkno = addressPXD(&(curpage->page->header.self));
 
             /* swap if on big endian machine */
-            if (type_jfs & JFS_SWAP_BYTES) {
-                memcpy( (xtpage_t *)buffer, curpage->page, sizeof(xtpage_t));
-                ujfs_swap_xtpage_t( (xtpage_t *)buffer );
-                rc = ujfs_rw_diskblocks(dev_ptr, blkno * aggr_block_size, PSIZE,
-                                        (xtpage_t *)buffer, PUT);
-            } else {
-                rc = ujfs_rw_diskblocks(dev_ptr, blkno * aggr_block_size, PSIZE,
-                                        curpage->page, PUT);
-            }
+            ujfs_swap_xtpage_t(curpage->page);
+            rc = ujfs_rw_diskblocks(dev_ptr, blkno * aggr_block_size, PSIZE,
+                                    curpage->page, PUT);
+            ujfs_swap_xtpage_t(curpage->page);
 
-            if ( rc != 0) {
-                if (type_jfs & JFS_SWAP_BYTES) free( buffer );
+            if ( rc != 0)
                 return rc;
-            }
+
             curpage = curpage->up;
         }
-        if (type_jfs & JFS_SWAP_BYTES) free( buffer );
 
         /* Write the bad block inode itself */
         rc = ujfs_rwinode( dev_ptr, bb_inode, BADBLOCK_I, PUT, aggr_block_size,
