@@ -37,7 +37,7 @@
 #include <stddef.h>
 #include <time.h>
 #include <errno.h>
-#include "jfs_byteorder.h"
+#include "jfs_endian.h"
 #include "jfs_filsys.h" 
 #include "jfs_dinode.h"
 #include "initmap.h"
@@ -49,7 +49,6 @@
 
 /* endian routines */
 extern uint32_t type_jfs;
-extern void ujfs_swap_dinode( dinode_t  *, int32_t, uint32_t );
 
 /*
  * NAME: init_aggr_inode_table
@@ -95,7 +94,7 @@ int32_t init_aggr_inode_table( int32_t        aggr_block_size,
    */
   buffer = calloc( INODE_EXTENT_SIZE, sizeof(char) );
   if( buffer == NULL ) {
-    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
     return( ENOMEM );
   }
 
@@ -139,16 +138,14 @@ int32_t init_aggr_inode_table( int32_t        aggr_block_size,
    */
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    /* swap gengen from aggr_inodes[AGGREGATE_I] in buffer */
-    buf_ai = ((struct dinode *)buffer) + AGGREGATE_I;
-    buf_ai->di_gengen = __le32_to_cpu(buf_ai->di_gengen);
-    for (i=0; i<num_aggr_inodes; i++) {
-      ujfs_swap_dinode( (dinode_t *)buffer, PUT, type_jfs );
-      buffer = (char *)buffer + sizeof(struct dinode);
-    }
-    buffer = (char *)buffer - (num_aggr_inodes * sizeof(struct dinode));
+  /* swap gengen from aggr_inodes[AGGREGATE_I] in buffer */
+  buf_ai = ((struct dinode *)buffer) + AGGREGATE_I;
+  buf_ai->di_gengen = __le32_to_cpu(buf_ai->di_gengen);
+  for (i=0; i<num_aggr_inodes; i++) {
+    ujfs_swap_dinode( (dinode_t *)buffer, PUT, type_jfs );
+    buffer = (char *)buffer + sizeof(struct dinode);
   }
+  buffer = (char *)buffer - (num_aggr_inodes * sizeof(struct dinode));
 
   rc = ujfs_rw_diskblocks( dev_ptr, table_loc, INODE_EXTENT_SIZE, buffer, PUT );
   free( buffer );
@@ -198,13 +195,13 @@ int32_t init_aggr_inode_table( int32_t        aggr_block_size,
  *      success: 0
  *      failure: any other value
  */
-int32_t init_fileset_inode_table( int32_t  aggr_block_size,
-                                  HFILE    dev_ptr,
-                                  int64_t  *inode_location,
-                                  int32_t  *inode_size,
-                                  int64_t  fileset_start,
-                                  int64_t  fileset_inode_map_loc,
-                                  int32_t  inostamp )
+int32_t init_fileset_inode_table( int32_t   aggr_block_size,
+                                  HFILE     dev_ptr,
+                                  int64_t   *inode_location,
+                                  int32_t   *inode_size,
+                                  int64_t   fileset_start,
+                                  int64_t   fileset_inode_map_loc,
+                                  uint32_t  inostamp )
 {
   void           *buffer, *bp;
   struct dinode  inode_buffer;
@@ -238,7 +235,7 @@ int32_t init_fileset_inode_table( int32_t  aggr_block_size,
   *inode_size = INODE_EXTENT_SIZE;
   bp = buffer = calloc( *inode_size, sizeof(char) );
   if( bp == NULL ) {
-    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+    message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
     return( ENOMEM );
   }
   /*
@@ -327,12 +324,10 @@ int32_t init_fileset_inode_table( int32_t  aggr_block_size,
    */
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    bp = buffer;
-    for (i=0; i<4; i++) {
-      ujfs_swap_dinode( (dinode_t *)bp, PUT, type_jfs );
-      bp = (char *)bp + sizeof(inode_buffer);
-    }
+  bp = buffer;
+  for (i=0; i<4; i++) {
+    ujfs_swap_dinode( (dinode_t *)bp, PUT, type_jfs );
+    bp = (char *)bp + sizeof(inode_buffer);
   }
 
   rc = ujfs_rw_diskblocks( dev_ptr, *inode_location, *inode_size, buffer,
@@ -381,12 +376,12 @@ int32_t init_fileset_inode_table( int32_t  aggr_block_size,
  *      success: 0
  *      failure: any other value
  */
-int32_t init_fileset_inodes( int32_t  aggr_block_size,
-                             HFILE    dev_ptr,
-                             int64_t  inode_map_loc,
-                             int32_t  inode_map_size,
-                             int64_t  fileset_start,
-                             int32_t  inostamp )
+int32_t init_fileset_inodes( int32_t   aggr_block_size,
+                             HFILE     dev_ptr,
+                             int64_t   inode_map_loc,
+                             int32_t   inode_map_size,
+                             int64_t   fileset_start,
+                             uint32_t  inostamp )
 {
   struct dinode  inode_buffer;
   uint32_t       inode_num;
@@ -474,7 +469,7 @@ void init_inode( struct dinode  *new_inode,
                  ino_data_type  inode_type,
                  int64_t        inoext_address,
                  int32_t        aggr_block_size,
-                 int32_t        inostamp )
+                 uint32_t       inostamp )
 {
   /*
    * Initialize inode with where this stuff lives
