@@ -30,10 +30,10 @@
 typedef enum { inline_data, extent_data, max_extent_data, no_data } ino_data_type;
 
 int32_t init_aggr_inode_table(int32_t, HFILE, struct dinode *, int32_t, int64_t, int64_t, int32_t, uint32_t);
-int32_t init_fileset_inode_table(int32_t, HFILE, int64_t *, int32_t *, int64_t, int64_t, int32_t);
-int32_t init_fileset_inodes(int32_t, HFILE, int64_t, int32_t, int64_t, int32_t);
+int32_t init_fileset_inode_table(int32_t, HFILE, int64_t *, int32_t *, int64_t, int64_t, uint32_t);
+int32_t init_fileset_inodes(int32_t, HFILE, int64_t, int32_t, int64_t, uint32_t);
 
 void init_inode(struct dinode *, int32_t, uint32_t, int64_t, int64_t, int64_t, mode_t,
-		        ino_data_type, int64_t, int32_t, int32_t);
+		        ino_data_type, int64_t, int32_t, uint32_t);
 
 #endif
