@@ -18,10 +18,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 
 #include "config.h"
 
+#include <fcntl.h>
 #include <unistd.h>
-#include <getopt.h>
 #include <sys/stat.h>
-#include <mntent.h>
+#include <sys/sysmacros.h>
 #include <jfs_types.h>
 #include <errno.h>
 #include <string.h>
@@ -29,7 +29,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #include <stdio.h>
 #include <time.h>
 #include <ctype.h>
-#include "jfs_byteorder.h"
+#include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_dinode.h"
 #include "jfs_superblock.h"
@@ -44,10 +44,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 #include "debug.h"
 #include "jfs_version.h"
 
-/* endian routines */
-extern uint32_t type_jfs;
-extern void ujfs_swap_dinode( dinode_t  *, int32_t, uint32_t );
-extern int jfs_native_flag(void);
+void mkfs_usage( void );
+
+uint32_t type_jfs;
 
 extern int Is_Device_Mounted ( char * );
 
@@ -69,6 +68,7 @@ char    msgstr[MAXSTR];
  * initialized when a new aggregate is created.  This does not include any
  * fileset inodes as those are initialized separately.
  */
+
 #define INIT_NUM_AGGR_INODES    (BADBLOCK_I + 1)
 
 static struct dinode    aggr_inodes[INIT_NUM_AGGR_INODES];
@@ -94,10 +94,10 @@ static struct dinode    aggr_inodes[INIT_NUM_AGGR_INODES];
  *      success: 0
  *      failure: any other value
  */
-static int32_t create_fileset( int32_t  dev_ptr,
-                               int32_t  aggr_block_size,
-                               int64_t  start_block,
-                               int32_t  inostamp)
+static int32_t create_fileset( int32_t   dev_ptr,
+                               int32_t   aggr_block_size,
+                               int64_t   start_block,
+                               uint32_t  inostamp)
 {
     int32_t  rc;
     int64_t  inode_table_loc, inode_map_loc;
@@ -167,11 +167,11 @@ static int32_t create_fileset( int32_t  dev_ptr,
  *      dev_ptr                 - open port of device to write to
  *      volume_label            - label for volume
  *      number_of_blocks        - number of blocks for aggregate
- *      compress                - indicates compression for the aggregate
  *      aggr_block_size         - block size for aggregate
  *      phys_block_size         - physical block size of device
  *      type_jfs                - JFS type to create
  *      verify_blocks           - indicates if we should verify every block
+ *	log_uuid		- uuid of log device
  *
  * NOTES: The superblocks are the last things written to disk.  In the event of
  *      a system crash during mkfs this device will not appear to have a real
@@ -186,18 +186,17 @@ static int32_t create_fileset( int32_t  dev_ptr,
  *      success: 0
  *      failure: any other value
  */
-#define L2BITSPERBYTE   3
-#define BITSPERPAGE     (PSIZE << L2BITSPERBYTE)
 static int32_t create_aggregate( int32_t   dev_ptr,
                                  char      *volume_label,
                                  int64_t   number_of_blocks,
-                                 int32_t   compress,
                                  int32_t   aggr_block_size,
                                  int32_t   phys_block_size,
                                  uint32_t  type_jfs,
+                                 char     *logdev,
                                  int64_t   logloc,
                                  int32_t   logsize,
-                                 bool      verify_blocks)
+                                 bool      verify_blocks,
+				 uuid_t    log_uuid)
 {
     struct superblock  aggr_superblock;
     void      *buffer;
@@ -254,7 +253,7 @@ static int32_t create_aggregate( int32_t   dev_ptr,
     reserved_size = AGGR_RSVD_BYTES;
     buffer = calloc( reserved_size, sizeof(char));
     if ( buffer == NULL ) {
-        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, OSO_MSG);
         return( ENOMEM );
     }
     rc = ujfs_rw_diskblocks( dev_ptr, 0, reserved_size, buffer, PUT );
@@ -386,25 +385,12 @@ static int32_t create_aggregate( int32_t   dev_ptr,
                secondary_ait_address/aggr_block_size);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        /* copy to buffer for swap */
-        buffer = malloc(sizeof(dinode_t));
-        if ( buffer == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-            return( ENOMEM );
-        }
-        memcpy( (dinode_t *)buffer, &fileset_inode, sizeof(dinode_t));
-        ujfs_swap_dinode( (dinode_t *)buffer, PUT, type_jfs );
+    ujfs_swap_dinode(&fileset_inode, PUT, type_jfs );
+    rc = ujfs_rw_diskblocks( dev_ptr,
+                             secondary_ait_address + FILESYSTEM_I * sizeof(struct dinode),
+                             sizeof(fileset_inode), &fileset_inode, PUT );
+    ujfs_swap_dinode(&fileset_inode, GET, type_jfs );
 
-        rc = ujfs_rw_diskblocks( dev_ptr,
-                                 secondary_ait_address + FILESYSTEM_I * sizeof(struct dinode),
-                                 sizeof(fileset_inode), (dinode_t *)buffer, PUT );
-        free( buffer );
-    } else {
-        rc = ujfs_rw_diskblocks( dev_ptr,
-                                 secondary_ait_address + FILESYSTEM_I * sizeof(struct dinode),
-                                 sizeof(fileset_inode), &fileset_inode, PUT );
-    }
     if ( rc != 0 ) return rc;
 
 
@@ -433,24 +419,11 @@ static int32_t create_aggregate( int32_t   dev_ptr,
                secondary_ait_address/aggr_block_size);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      /* copy to buffer for swap */
-        buffer = malloc(sizeof(dinode_t));
-        if ( buffer == NULL) {
-            message_user(MSG_OSO_INSUFF_MEMORY, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-            return( ENOMEM );
-        }
-        memcpy( (dinode_t *)buffer, &(aggr_inodes[BADBLOCK_I]), sizeof(dinode_t));
-        ujfs_swap_dinode( (dinode_t *)buffer, PUT, type_jfs );
-        rc = ujfs_rw_diskblocks( dev_ptr,
-                                 secondary_ait_address + BADBLOCK_I * sizeof(struct dinode),
-                                 sizeof(struct dinode), (dinode_t *)buffer, PUT );
-        free( buffer );
-    } else {
-        rc = ujfs_rw_diskblocks( dev_ptr,
-                                 secondary_ait_address + BADBLOCK_I * sizeof(struct dinode),
-                                 sizeof(struct dinode), &(aggr_inodes[BADBLOCK_I]), PUT );
-    }
+    ujfs_swap_dinode(&aggr_inodes[BADBLOCK_I], PUT, type_jfs);
+    rc = ujfs_rw_diskblocks( dev_ptr,
+                             secondary_ait_address + BADBLOCK_I * sizeof(struct dinode),
+                             sizeof(struct dinode), &(aggr_inodes[BADBLOCK_I]), PUT );
+    ujfs_swap_dinode(&aggr_inodes[BADBLOCK_I], GET, type_jfs);
 
     if ( rc != 0 ) return rc;
 
@@ -463,16 +436,77 @@ static int32_t create_aggregate( int32_t   dev_ptr,
     /*
      * Initialize Aggregate Superblock - Both primary and secondary
      */
-    rc = ujfs_init_superblock( &aggr_superblock, dev_ptr, volume_label,
-                               number_of_blocks, compress, aggr_block_size,
-                               phys_block_size, type_jfs,
-                               secondary_ait_address/aggr_block_size,
-                               INODE_EXTENT_SIZE/aggr_block_size, AGsize,
-                               fsck_wspace_address, fsck_wspace_length,
-                               fsck_svclog_length, logloc,
-                               logsize, secondary_aimap_address,
-                               aggr_inode_map_sz/aggr_block_size );
+    memcpy(aggr_superblock.s_magic, JFS_MAGIC, strlen(JFS_MAGIC));
+    /*
+     * JFS_VERSION should have been upped to 2 when the linux-native format
+     * split from OS/2.  However, we don't want to force the use of the
+     * latest JFS kernel code unless we're using an outline log.  In that
+     * case we want to set s_version to 2 to mandate a recent JFS driver.
+     */
+    /* aggr_superblock.s_version = (type_jfs | JFS_OS2) ? 1 : JFS_VERSION; */
+    aggr_superblock.s_version = (type_jfs | JFS_INLINELOG) ? 1 : JFS_VERSION;
+    aggr_superblock.s_size = number_of_blocks *
+	    		     (aggr_block_size / phys_block_size);
+    aggr_superblock.s_bsize = aggr_block_size;
+    aggr_superblock.s_l2bsize = log2shift(aggr_block_size);
+    aggr_superblock.s_l2bfactor = log2shift(aggr_block_size / phys_block_size);
+    aggr_superblock.s_pbsize = phys_block_size;
+    aggr_superblock.s_l2pbsize = log2shift(phys_block_size);
+    aggr_superblock.pad = 0;
+    aggr_superblock.s_agsize = AGsize;
+    aggr_superblock.s_flag = type_jfs;
+    aggr_superblock.s_state = FM_CLEAN;
+    aggr_superblock.s_compress = 0;
+    PXDaddress(&aggr_superblock.s_ait2,
+	       secondary_ait_address / aggr_block_size);
+    PXDlength(&aggr_superblock.s_ait2, INODE_EXTENT_SIZE / aggr_block_size);
+    PXDaddress(&aggr_superblock.s_aim2, secondary_aimap_address);
+    PXDlength(&aggr_superblock.s_aim2, aggr_inode_map_sz / aggr_block_size);
 
+    if (logdev[0]) {
+	    struct stat st;
+
+	    if (stat(logdev, &st))
+		    return errno;
+
+	    aggr_superblock.s_logdev = dev_to_kdev(st.st_rdev);
+	    memset(&aggr_superblock.s_logpxd, 0, sizeof(pxd_t));
+	    uuid_copy(aggr_superblock.s_loguuid, log_uuid);
+    } else {
+	    aggr_superblock.s_logdev = 0;
+	    PXDaddress(&aggr_superblock.s_logpxd, logloc);
+	    PXDlength(&aggr_superblock.s_logpxd, logsize);
+    }
+
+    aggr_superblock.s_logserial = 0;
+    PXDaddress(&aggr_superblock.s_fsckpxd, fsck_wspace_address);
+    PXDlength(&aggr_superblock.s_fsckpxd, fsck_wspace_length);
+    aggr_superblock.s_time.tv_sec = time(NULL);
+    aggr_superblock.s_time.tv_nsec = 0;
+    aggr_superblock.s_fsckloglen = fsck_svclog_length;
+    aggr_superblock.s_fscklog = 0;
+    strncpy(aggr_superblock.s_fpack, volume_label, LV_NAME_SIZE);
+
+    /* extendfs stuff */
+    aggr_superblock.s_xsize = 0;
+    memset(&aggr_superblock.s_xfsckpxd, 0, sizeof(pxd_t));
+    memset(&aggr_superblock.s_xlogpxd, 0, sizeof(pxd_t));
+
+    uuid_generate(aggr_superblock.s_uuid);
+    strncpy(aggr_superblock.s_label, volume_label, 16);
+
+    /* TODO: store log uuid */
+
+    /* Write both the primare and secondary superblocks to disk */
+    rc = ujfs_validate_super(&aggr_superblock);
+    if (rc)
+	    return rc;
+
+    rc = ujfs_put_superblk(dev_ptr, &aggr_superblock, 1);
+    if (rc)
+	    return rc;
+
+    rc = ujfs_put_superblk(dev_ptr, &aggr_superblock, 0);
     return rc;
 }
 
@@ -538,32 +572,24 @@ int main(int argc,char * argv[])
     int64_t   number_of_bytes = 0, bytes_on_device;
     int64_t   number_of_blocks, logloc = 0, logsize_in_bytes = 0;
     char      logdev[255] = { '\0'}; /* Need to use a macro for this size */
-    int32_t   compress = 0;
     int32_t   aggr_block_size = 0;
-    int32_t   phys_block_size, logsize = 0;
+    int32_t   phys_block_size = PBSIZE, logsize = 0;
     HFILE     dev_handle;
     uint32_t  type_commit = JFS_GROUPCOMMIT;
     bool      verify_blocks = false;
     bool      no_questions_asked = false;
-    char      *user_input;
+    uuid_t    log_uuid;
 
     printf( "mkfs.jfs version %s, %s\n", 
             VERSION, JFSUTILS_DATE);
 
-    /* Are there any command line arguments? */
-    if ( argc < 2) {
-        /* We have no command line arguments and don't know which device to format. Abort! */
-        message_user(MSG_OSO_CANT_FIND_DRIVE, NULL,0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-        return EINVAL;
-    }
-
     type_jfs = JFS_LINUX | JFS_DIR_INDEX;
 
     /*
      * Parse command line arguments
      */
 
-   	while ((c = getopt (argc, argv, "cfL:Oqs:V")) != EOF) {
+   	while ((c = getopt (argc, argv, "cj:fL:Oqs:V")) != EOF) {
 		switch (c) {
 #ifdef BLOCK_SIZE /* add b: to getopt call */
             case 'b':
@@ -575,12 +601,10 @@ int main(int argc,char * argv[])
                 /* check for bad blocks */
                 verify_blocks = true;
                 break;
-#ifdef LOG_DEVICE /* add d: to getopt call */
-            case 'd':
+            case 'j':
                 /* external log device */
                 strcpy( logdev, optarg );
                 break;
-#endif
             case 'L':
                 /* volume label */
                 strncpy( volume_label, optarg, LV_NAME_SIZE );
@@ -588,7 +612,7 @@ int main(int argc,char * argv[])
             case 'O':
                 /* case insensitive for OS/2 compatibility */
                 type_jfs |= JFS_OS2;
-                type_jfs &= ~(JFS_LINUX);
+                type_jfs &= ~(JFS_LINUX|JFS_DIR_INDEX);
                 break;
             case 'f':
             case 'q':
@@ -599,8 +623,8 @@ int main(int argc,char * argv[])
                 /* log size */
                 logsize = strtol(optarg, NULL, 0);
                 if(!logsize) {
-                    printf("\nInvalid log size specified for -s.\n\n");
-                    message_user(MSG_OSO_MKFS_USAGE, (char **) &argp, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+                    printf("\nLog size not specified for -s.\n");
+                    mkfs_usage();
                     return EINVAL;
                 }
                 logsize_in_bytes = ((int64_t) logsize) * MEGABYTE;
@@ -610,22 +634,18 @@ int main(int argc,char * argv[])
                 exit(0);
                 break;
             default:
-                message_user(MSG_OSO_MKFS_USAGE, (char **) &argp, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+                mkfs_usage();
                 return EINVAL;
         }    	
     }
 
-    if (optind == argc) {
-        message_user(MSG_OSO_MKFS_USAGE, (char **) &argp, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+    if (optind != argc-1) {
+        printf("\nError: Device not specified or command format error\n");
+        mkfs_usage();
         return EINVAL;
     }
-	device_name = argv[optind];
 
-    /* Has a device been specified? */
-    if (device_name == NULL) {
-        message_user(MSG_OSO_CANT_FIND_DRIVE, NULL,0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-        return EINVAL;
-    }
+	device_name = argv[optind];
 
     /* Check for block device, otherwise mkfs gives misunderstanding errors - MSG_OSO_DISK_LOCKED */
     {
@@ -635,12 +655,12 @@ int main(int argc,char * argv[])
 		/* Do we have a block special device?  Get the stat data for the device and find out. */
 		rc = stat(device_name, &stat_data);
 		if ( rc != 0) {
-		    message_user(MSG_OSO_CANT_FIND_DRIVE, NULL,0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+		    message_user(MSG_OSO_CANT_FIND_DRIVE, NULL,0, OSO_MSG);
 		    return EINVAL;
 		}
 	    /* Do we have a block special device? */
 		if ( !S_ISBLK(stat_data.st_mode) ) {
-            message_user(MSG_OSO_NOT_VALID_BLOCK_DEVICE, (char **) &argp, 1, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_NOT_VALID_BLOCK_DEVICE, (char **) &argp, 1, OSO_MSG);
 		    return EINVAL;
 		}
     }
@@ -649,7 +669,7 @@ int main(int argc,char * argv[])
     rc = Is_Device_Mounted(device_name);
     if ( rc ) {
         /* The device is mounted!  Output an error and abort. */
-        message_user(rc,NULL, 0, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+        message_user(rc, NULL, 0, JFS_MSG);
         return ERROR_INVALID_ACCESS;
     }
 
@@ -657,15 +677,15 @@ int main(int argc,char * argv[])
      * Open the device and lock it from all others
      * Get the physical block size of the device.
      */
-    rc = ujfs_open_device( device_name, &dev_handle, &phys_block_size, RDWR_EXCL );
-    if ( rc != 0 ) {
-        /* message_user(MSG_OSO_DISK_LOCKED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG); */
+    dev_handle = open(device_name, O_RDWR|O_EXCL, 0);
+    if (dev_handle < 0) {
+        /* message_user(MSG_OSO_DISK_LOCKED, NULL, 0, OSO_MSG); */
         printf("\nError: Cannot open device %s.\n", device_name);
-        return( rc );
+        return( ERROR_FILE_NOT_FOUND );
     }
 
     if ( Bad_Device(dev_handle) ) {
-        message_user(MSG_OSO_DISK_LOCKED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_DISK_LOCKED, NULL, 0, OSO_MSG);
         return( ERROR_FILE_NOT_FOUND );
     }
 
@@ -682,9 +702,9 @@ int main(int argc,char * argv[])
         sprintf(msgstr, "%d", aggr_block_size);
         msg_parms[0] = msgstr;
         msg_parms[1] = "BS";
-        message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2, OSO_MSG);
         rc = EINVAL;
-        ujfs_close( dev_handle );
+        close( dev_handle );
         return(rc);
     } else {
         /*
@@ -694,9 +714,9 @@ int main(int argc,char * argv[])
             sprintf(msgstr, "%d", aggr_block_size);
             msg_parms[0] = msgstr;
             msg_parms[1] = "BS";
-            message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_VALUE_NOT_ALLOWED, msg_parms, 2, OSO_MSG);
             rc = EINVAL;
-            ujfs_close( dev_handle );
+            close( dev_handle );
             return(rc);
         }
     }
@@ -707,8 +727,8 @@ int main(int argc,char * argv[])
     rc = ujfs_get_dev_size( dev_handle, &bytes_on_device );
     if ( rc != 0 ) {
         DBG_ERROR(("ujfs_get_dev_size: FAILED rc = %lld\n", rc ))
-        message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
-        ujfs_close( dev_handle );
+        message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
+        close( dev_handle );
         return(rc);
     }
 
@@ -725,15 +745,15 @@ int main(int argc,char * argv[])
     if (number_of_bytes < MINJFS) {
         if (number_of_bytes == 0) {
             /* Not readable at all */
-            message_user(MSG_JFS_BAD_PART, msg_parms, 0, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+            message_user(MSG_JFS_BAD_PART, msg_parms, 0, JFS_MSG);
 	    } else {
             /* Really too small */
             strcpy(msgstr,MINJFSTEXT);
             msg_parms[0] = msgstr;
-            message_user(MSG_JFS_PART_SMALL, msg_parms, 1, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+            message_user(MSG_JFS_PART_SMALL, msg_parms, 1, JFS_MSG);
         }
         rc = EINVAL;
-        ujfs_close( dev_handle );
+        close( dev_handle );
         return(rc);
     }
 
@@ -743,22 +763,25 @@ int main(int argc,char * argv[])
     number_of_blocks = number_of_bytes / aggr_block_size;
     DBG_TRACE(("number of blocks = %lld\n", number_of_blocks ))
 
-    /* see if we're on a big endian computer;
-     * if so, set the flag indicating that we must
-     * swap bytes when saving to or reading from disk
-     */
-    type_jfs |= jfs_native_flag();
-
     /* now ask the user if he really wants to destoy his data */
-    if (no_questions_asked == false) do {
-        msg_parms[0] = device_name;
-        user_input = message_user(MSG_OSO_DESTROY_DATA, msg_parms, 1, STDOUT_CODE, YES_NO_RESPONSE, OSO_MSG);
-        if (*user_input == 'N') {
-            ujfs_close( dev_handle );
-            return 0;
-        }
-    } while (*user_input != 'Y' );
+    if (no_questions_asked == false) {
+	msg_parms[0] = device_name;
+	message_user(MSG_OSO_DESTROY_DATA, msg_parms, 1, OSO_MSG);
+	if (logdev[0]) {
+		msg_parms[0] = logdev;
+		message_user(MSG_OSO_DESTROY_DATA, msg_parms, 1, OSO_MSG);
+	}
+	do {
+	    printf("\nContinue? (Y/N) ");
+	    c = getchar();
 
+	    if (c == 'n' || c == 'N') {
+		close(dev_handle);
+		return 0;
+	    } else if (c == EOF)
+		abort();
+	} while (c != 'y' && c != 'Y');
+    }
 
     /*
      * Create journal log for aggregate to use
@@ -768,16 +791,26 @@ int main(int argc,char * argv[])
      * a default method of finding and creating the log.
      */
     if ( logdev[0] != '\0' ) {
+	int fd;
+
         /* A log device was specified on the command line.  Call jfs_logform()
          * to initialize the log */
-        rc = jfs_logform( -1, aggr_block_size, log2shift(aggr_block_size),
-                          type_jfs|type_commit, 0, 0, logdev, 0 );
+	fd = open(logdev, O_RDWR | O_EXCL, 0);
+	if (fd < 0) {
+            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
+            close( dev_handle );
+	    return -1;
+	}
+	uuid_clear(log_uuid);
+        rc = jfs_logform(fd, aggr_block_size, log2shift(aggr_block_size),
+                          type_jfs|type_commit, 0, 0, log_uuid);
+	close(fd);
         if ( rc != 0 ) {
-            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
             DBG_ERROR(("Internal error: Format failed rc=%x\n",rc))
 
             /* Unlock device whether or not creation of aggregate succeeded.*/
-            ujfs_close( dev_handle );
+            close( dev_handle );
 
             /* Exit with return code */
             return( rc );
@@ -803,13 +836,13 @@ int main(int argc,char * argv[])
         logsize = logsize_in_bytes / aggr_block_size;
 
         if ( logsize >= (number_of_blocks / MAX_LOG_PERCENTAGE) ) {
-            message_user(MSG_JFS_LOG_LARGE, NULL, 0, STDOUT_CODE, NO_RESPONSE, JFS_MSG);
+            message_user(MSG_JFS_LOG_LARGE, NULL, 0, JFS_MSG);
             rc = ENOSPC;
-            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
             DBG_ERROR(("Internal error: Format failed rc=%x\n",rc))
 
             /* Unlock device whether or not creation of aggregate succeeded.*/
-            ujfs_close( dev_handle );
+            close( dev_handle );
 
             /* Exit with return code */
             return( rc );
@@ -820,13 +853,13 @@ int main(int argc,char * argv[])
         l2absize = log2shift(aggr_block_size);
         rc = jfs_logform( dev_handle, aggr_block_size,
                           l2absize, type_jfs|type_commit, logloc,
-                          logsize, NULL, 0 );
+                          logsize, NULL);
         if ( rc != 0 ) {
-            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+            message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
             DBG_ERROR(("Internal error: Format failed rc=%x\n",rc))
 
             /* Unlock device whether or not creation of aggregate succeeded.*/
-            ujfs_close( dev_handle );
+            close( dev_handle );
 
             /* Exit with return code */
             return( rc );
@@ -836,29 +869,44 @@ int main(int argc,char * argv[])
     /*
      * Create aggregate, which will also create a fileset as necessary
      */
-    rc = create_aggregate( dev_handle, volume_label, number_of_blocks, compress,
+    rc = create_aggregate( dev_handle, volume_label, number_of_blocks,
                            aggr_block_size, phys_block_size,
-                           type_jfs|type_commit, logloc, logsize,
-                           verify_blocks);
+                           type_jfs|type_commit, logdev, logloc, logsize,
+                           verify_blocks, log_uuid);
 
     /* Unlock and close the volume */
-    ujfs_close( dev_handle );
+    close( dev_handle );
 
     /* Format Complete message */
     if ( rc == 0 ) {
-        message_user(MSG_OSO_FORMAT_COMPLETE, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_FORMAT_COMPLETE, NULL, 0, OSO_MSG);
         /* stat messages */
         sprintf(msgstr,"%lld", (long long)(number_of_bytes / 1024) );
         msg_parms[0] = msgstr;                        /* total disk space msg           */
-        message_user(MSG_OSO_DISK_SPACE2, msg_parms, 1, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_DISK_SPACE2, msg_parms, 1, OSO_MSG);
 
     }
 
     if (rc) {
-        message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, STDOUT_CODE, NO_RESPONSE, OSO_MSG);
+        message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
         DBG_ERROR(("Internal error: Format failed rc=%x\n",rc))
     }
 
     /* Exit */
     return rc;
 }
+
+
+void mkfs_usage()
+{
+    printf("\nUsage:  mkfs.jfs [-cOqV] [-L vol_label] [-s log_size] device\n");
+    printf("\nEmergnecy help:\n"
+           " -c            Check device for bad blocks before building file system.\n"
+           " -O            Provide case-insensitive support for OS/2 compatability.\n"
+           " -q            Quiet execution.\n"
+           " -V            Print version information only.\n"
+           " -L vol_label  Set volume label for the file system.\n"
+           " -s log_size   Set log size (in megabytes).\n"
+           " -j log_device Set log device. (Experimental)\n");
+    return;
+}
