@@ -46,7 +46,6 @@
  *
  *   FUNCTIONS:
  *		main
- *		dump_msg
  *		dump_service_log
  *		final_processing
  *		fscklog_fill_buffer
@@ -68,20 +67,19 @@
 
 #include <string.h>
 #include <stdlib.h>
-#include <getopt.h>
+#include <unistd.h>
 
 #include "config.h"
 #include "jfs_version.h"
 #include "jfs_types.h"
 
-#define fsck_highest_msgid_defined 399
-
 /*
  * includes from JFS fsck
  */
 #include "fsckmsgc.h"         /* message constants */
 #include "fsckmsge.h"         /* message text, all messages, in English */
 #include "fscklog.h"          /* fsck service log */
+#include "xfsck.h"
 
 
 /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -143,8 +141,6 @@ unsigned long  msgs_txt_maxlen = 512;
  *
  */
 
-void dump_msg( int, int );
-
 void dump_service_log( void );
 
 int32_t final_processing ( void ) ;
@@ -221,36 +217,6 @@ int main(int argc, char **argv )
 }  /* end of main() */
 
 
-/*****************************************************************************
- * NAME: dump_msg
- *
- * FUNCTION: Dump the contents of a message record in the extracted
- *           fsck service log.
- *
- * PARAMETERS:
- *      ?                 - input -
- *      ?                 - returned -
- *
- * NOTES:  none
- *
- * RETURNS:
- *	nothing
- */
-void dump_msg( int  msg_num, int  num_inserts )
-{
-  int  prmidx;
-
-  printf(" message number : %d\n", msg_num );
-  for ( prmidx=0; prmidx < num_inserts; prmidx++ ) {
-    printf("  insert #%d: length: %03d   text: %s\n",
-           prmidx, msgprmidx[prmidx], msgprms[prmidx] );
-  }
-  printf("\n");
-
-  return;
-}  /* end dump_msg() */
-
-
 /***************************************************************************
  * NAME: dump_service_log
  *
@@ -345,7 +311,7 @@ void dump_service_log( )
             /*
              * dump the message record
              */
-            dump_msg( hdptr->msg_num, hdptr->num_parms );
+            send_msg( hdptr->msg_num-10000, hdptr->num_parms );
           }  /* end the the record looks ok */
 
           /*
