@@ -65,17 +65,20 @@
  *
  */
 
-#include <getopt.h>
+#include <unistd.h>
 /*
  * includes from JFS fsck
  */
 #include "config.h"
+
+#include <fcntl.h>
+
 #include "xfsck.h"            /* fsck constants */
 #include "fsckwsp.h"          /* fsck workspace mappings */
 #include "fsckmsgc.h"         /* message constants */
 #include "fsckmsge.h"         /* message text, all messages, in english */
 #include "fsckmsgp.h"         /* message processing protocols           */
-#include "jfs_byteorder.h"
+#include "jfs_endian.h"
 #include "jfs_version.h"      /* version number and date for utils      */
 
 #define fsck_READ  1
@@ -314,6 +317,10 @@ void extract_service_log( )
       if( hdptr->entry_length == 0 ) {  /* no more entries in this buffer */
         local_recptr->this_buffer_last_message = -1;
       } else { /* this entry_length != 0 */
+
+        /* swap if on big endian machine */
+        ujfs_swap_fscklog_entry_hdr_t( hdptr );
+
         log_entry = (char *) hdptr;
         log_entry_pos = sizeof(fscklog_entry_hdr_t);
 
@@ -419,7 +426,7 @@ retcode_t  final_processing ( )
      * Close the device
      */
   if( local_recptr->device_is_open ) {
-    pf_rc = ujfs_close(Dev_IOPort);
+    pf_rc = close(Dev_IOPort);
   }
 
     /*
@@ -682,21 +689,18 @@ retcode_t initial_processing ( int32_t argc, char **argv )
  */
 retcode_t open_device_read ( char  *Device )
 {
-  int32_t  openrd_rc = 0;
- 
-  openrd_rc = ujfs_open_device(Device,&Dev_IOPort, &Dev_SectorSize , READONLY);
-  if ( openrd_rc == NO_ERROR ) {  
-    /* now open for read, allow read/write */
-    Dev_blksize = Dev_SectorSize;
-  } else {  /* log failure to open */
-    sprintf( message_parm_0, "%d", openrd_rc );
+  Dev_IOPort = open(Device, O_RDONLY, 0);
+  if (Dev_IOPort < 0) {
+    sprintf( message_parm_0, "%d", ERROR_FILE_NOT_FOUND );
     msgprms[0] = message_parm_0;
     msgprmidx[0] = 0;
     send_msg( fsck_DEVOPENRDRC, 1 );
+    return ERROR_FILE_NOT_FOUND;
   }
 
-  return( openrd_rc );
-}  /* end of open_device_read ( ) */
+  Dev_blksize = Dev_SectorSize = PBSIZE;
+  return 0;
+}
 
 
 /*****************************************************************************
@@ -1064,11 +1068,7 @@ void send_msg( int  msg_num, int  num_inserts )
        * issue the message in the local language if it has been 
        * translated, otherwise issue it in english
        */
-  if( MsgProtocol[msg_num][MP_STREAM] == fsck_out ) {
-    fprintf( stdout, msgs_txt_ptr );
-  } else {
-    fprintf( stderr, msgs_txt_ptr );
-  }
+  fprintf( stdout, msgs_txt_ptr );
 
   return;
 }  /* end send_msg() */
