@@ -23,6 +23,8 @@
  *
 */
 
+#include <limits.h>
+
 #include "xpeek.h"
  
 /* JFS includes */
@@ -31,12 +33,14 @@
 #include <jfs_filsys.h>
 
 #include "unicode_to_utf8.h"
-#include "jfs_byteorder.h"
+#include "jfs_endian.h"
 #include "jfs_unicode.h"
 
 /* libfs includes */
 #include <inode.h>
 
+extern uint32_t type_jfs;
+
 void print_direntry(dtslot_t *, uint8_t);
 char display_leaf_slots(dtslot_t *, int8_t *, int8_t, int32_t *);
 char display_internal_slots(dtslot_t *, int8_t *, int8_t, int32_t *);
@@ -49,14 +53,7 @@ char display_extent_page(int64_t);
 void display_xtpage(xtpage_t *);
 
 void strToUcs(UniChar *, char *, int32_t);
-char UTF8_Buffer[8 * MAXPATHLEN];
-
-/* endian routines */
-extern uint32_t type_jfs;
-extern void ujfs_swap_xtpage_t( xtpage_t * );
-extern void ujfs_swap_dtpage_t( dtpage_t *, uint32_t );
-extern void ujfs_swap_dinode( dinode_t *, int32_t, uint32_t );
-
+char UTF8_Buffer[8 * PATH_MAX];
 
 void directory()
 {
@@ -107,9 +104,7 @@ void directory()
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dinode( &inode, GET, type_jfs ); 
-  }
+  ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
   if ((inode.di_mode & IFMT) != IFDIR) {
     fputs("directory: Not a directory!\n", stderr);
@@ -142,9 +137,7 @@ descend:
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dtpage_t( &dtree, type_jfs );
-  }
+  ujfs_swap_dtpage_t( &dtree, type_jfs );
 
   stbl = (uint8_t *)&(dtree.slot[dtree.header.stblindex]);
   if (!(dtree.header.flag & BT_LEAF)) {
@@ -166,9 +159,7 @@ next_leaf:
     }
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dtpage_t( &dtree, type_jfs );
-    }
+    ujfs_swap_dtpage_t( &dtree, type_jfs );
 
     stbl = (uint8_t *)&(dtree.slot[dtree.header.stblindex]);
     goto next_leaf;
@@ -265,9 +256,7 @@ void dtree()
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dinode( &inode, GET, type_jfs ); 
-  }
+  ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
   if ((inode.di_mode & IFMT) != IFDIR) {
     fputs("dtree: Not a directory!\n", stderr);
@@ -361,21 +350,17 @@ retry:
       }
 
       /* swap if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-          ujfs_swap_dinode( &inode, PUT, type_jfs ); 
-      }
+      ujfs_swap_dinode( &inode, PUT, type_jfs ); 
 
       if (xWrite(inode_address, sizeof(dinode_t), (char *)&inode)) {
         fputs("dtree: error writing inode\n\n", stderr);
         /* swap back if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dinode( &inode, GET, type_jfs ); 
+        ujfs_swap_dinode( &inode, GET, type_jfs ); 
         return;
       }
 
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-          ujfs_swap_dinode( &inode, GET, type_jfs ); 
-      }
+      ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
       goto redisplay;
     }
@@ -393,21 +378,17 @@ retry:
   if (changed) {
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dinode( &inode, PUT, type_jfs ); 
-    }
+    ujfs_swap_dinode( &inode, PUT, type_jfs ); 
 
     if (xWrite(inode_address, sizeof(dinode_t), (char *)&inode)) {
       fputs("dtree: error writing inode\n\n", stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dinode( &inode, GET, type_jfs ); 
+      ujfs_swap_dinode( &inode, GET, type_jfs ); 
       return;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_dinode( &inode, GET, type_jfs ); 
-    }
+    ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
     changed = 0;
   }
@@ -468,9 +449,7 @@ void xtree()
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dinode( &inode, GET, type_jfs ); 
-  }
+  ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
   if ((inode.di_mode & IFMT) == IFDIR)
 	xtree = (xtpage_t *)&(inode.di_dirtable);
@@ -523,21 +502,17 @@ retry:
       }
 
       /* swap if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_dinode( &inode, PUT, type_jfs ); 
-      }
+      ujfs_swap_dinode( &inode, PUT, type_jfs ); 
 
       if (xWrite(inode_address, sizeof(dinode_t), (char *)&inode)) {
         fputs("xtree: error writing inode\n\n", stderr);
         /* swap back if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dinode( &inode, GET, type_jfs ); 
+        ujfs_swap_dinode( &inode, GET, type_jfs ); 
         return;
       }
 
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_dinode( &inode, GET, type_jfs ); 
-      }
+      ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
       goto redisplay;
     }
@@ -555,21 +530,17 @@ retry:
   if (changed) {
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dinode( &inode, PUT, type_jfs ); 
-    }
+    ujfs_swap_dinode( &inode, PUT, type_jfs ); 
 
     if (xWrite(inode_address, sizeof(dinode_t), (char *)&inode)) {
       fputs("xtree: error writing inode\n\n", stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dinode( &inode, GET, type_jfs ); 
+      ujfs_swap_dinode( &inode, GET, type_jfs ); 
       return;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dinode( &inode, GET, type_jfs ); 
-    }
+    ujfs_swap_dinode( &inode, GET, type_jfs ); 
 
     changed = 0;
   }
@@ -692,7 +663,7 @@ char display_slot( dtslot_t  *slot,
   memset(UTF8_Buffer,0,sizeof(UTF8_Buffer));
 
   /* Convert the name into UTF8 */
-  Unicode_String_to_UTF8_String(UTF8_Buffer, slot[index].name, MAXPATHLEN);
+  Unicode_String_to_UTF8_String(UTF8_Buffer, slot[index].name, PATH_MAX);
 
   printf("[3] name\t%.15s\n", UTF8_Buffer);
 
@@ -830,9 +801,7 @@ char display_internal_xtpage(xad_t  xad)
   } else {
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_xtpage_t( xtree );
-    }
+    ujfs_swap_xtpage_t( xtree );
 
 redisplay:
 
@@ -879,21 +848,17 @@ retry:
         }
 
         /* swap if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) {
-          ujfs_swap_xtpage_t( xtree ); 
-        }
+        ujfs_swap_xtpage_t( xtree ); 
 
         if (xWrite(xtpage_address, sizeof(xtpage_t), (char *)xtree)) {
           fputs("xtree: error writing xtpage\n\n", stderr);
           /* swap back if on big endian machine */
-          if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_xtpage_t( xtree ); 
+          ujfs_swap_xtpage_t( xtree ); 
           return result;
         }
 
         /* swap back if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) {
-          ujfs_swap_xtpage_t( xtree ); 
-        }
+        ujfs_swap_xtpage_t( xtree ); 
 
         goto redisplay;
       }
@@ -911,21 +876,17 @@ retry:
     if (changed) {
 
       /* swap if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_xtpage_t( xtree ); 
-      }
+      ujfs_swap_xtpage_t( xtree ); 
 
       if (xWrite(xtpage_address, sizeof(xtpage_t), (char *)xtree)) {
         fputs("xtree: error writing xtpage\n\n", stderr);
         /* swap back if on big endian machine */
-        if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_xtpage_t( xtree ); 
+        ujfs_swap_xtpage_t( xtree ); 
         return result;
       }
 
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) {
-        ujfs_swap_xtpage_t( xtree ); 
-      }
+      ujfs_swap_xtpage_t( xtree ); 
 
       changed = 0;
     }
@@ -951,9 +912,7 @@ char display_extent_page(int64_t  address)
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dtpage_t( &node, type_jfs );
-  }
+  ujfs_swap_dtpage_t( &node, type_jfs );
 
 
 redisplay5:
@@ -1009,21 +968,17 @@ redisplay5:
   if (changed) {
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dtpage_t( &node, type_jfs ); 
-    }
+    ujfs_swap_dtpage_t( &node, type_jfs ); 
 
     if (xWrite(address << l2bsize, sizeof(dtpage_t), (char *)&node)) {
       fputs("display_extent_page: error writing node\n\n", stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dtpage_t( &node, type_jfs ); 
+      ujfs_swap_dtpage_t( &node, type_jfs ); 
       return 0;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dtpage_t( &node, type_jfs ); 
-    }
+    ujfs_swap_dtpage_t( &node, type_jfs ); 
 
     changed = 0;
   }
