@@ -27,6 +27,7 @@
 #include <jfs_dmap.h>
 
 /* libfs includes */
+#include <jfs_endian.h>
 #include <inode.h>
 #include <devices.h>
 
@@ -64,13 +65,7 @@ int32_t  display_map(uint32_t *, int32_t);       /* iag.c */
 int32_t  dmap_level; /* Maximum level of dtree */
 int32_t  dmap_l2bpp; /* log 2 of blocks per page */
 
-/* endian routines */
 extern uint32_t type_jfs;
-extern void ujfs_swap_dmapctl_t( dmapctl_t  * );
-extern void ujfs_swap_dbmap_t( dbmap_t * );
-extern void ujfs_swap_dmap_t( dmap_t  * );
-extern void ujfs_swap_dinode( dinode_t *, int32_t, uint32_t );
-
 
 void dmap()
 {
@@ -93,9 +88,7 @@ void dmap()
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dinode( &bmap_inode, GET, type_jfs ); 
-  }
+  ujfs_swap_dinode( &bmap_inode, GET, type_jfs ); 
 
   /* Read overall control page for the map */
 
@@ -107,9 +100,7 @@ void dmap()
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dbmap_t( &cntl_page ); 
-  }
+  ujfs_swap_dbmap_t( &cntl_page ); 
 
   /* Useful stuff */
   dmap_level = BMAPSZTOLEV(cntl_page.dn_mapsize);
@@ -206,23 +197,19 @@ dbmap_retry:
     rc = display_agfree(hdr->dn_agfree);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dbmap_t( hdr ); 
-    }
+    ujfs_swap_dbmap_t( hdr ); 
 
     if ((rc & XPEEK_CHANGED) &&
         xWrite(hdr_addr, sizeof(dbmap_t), (char *)hdr)) {
       fputs("display_dbmap: error writing control header\n\n",
             stderr);
       /* swap if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dbmap_t( hdr ); 
+      ujfs_swap_dbmap_t( hdr ); 
       return DMAP_EXIT;
     }
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dbmap_t( hdr ); 
-    }
+    ujfs_swap_dbmap_t( hdr ); 
 
     if (rc & XPEEK_REDISPLAY)
       goto dbmap_redisplay;
@@ -284,22 +271,18 @@ dbmap_retry:
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dbmap_t( hdr ); 
-  }
+  ujfs_swap_dbmap_t( hdr ); 
 
   if (xWrite(hdr_addr, sizeof(dbmap_t), (char *)hdr)) {
     fputs("display_dbmap: error writing control header\n\n",
           stderr);
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dbmap_t( hdr ); 
+    ujfs_swap_dbmap_t( hdr ); 
     return DMAP_EXIT;
   }
 
   /* swap back if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dbmap_t( hdr ); 
-  }
+  ujfs_swap_dbmap_t( hdr ); 
 
   goto dbmap_redisplay;
 }
@@ -337,9 +320,7 @@ int32_t display_cpage( dinode_t  *bmap_inode,
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dmapctl_t( &ctl_page ); 
-  }
+  ujfs_swap_dmapctl_t( &ctl_page ); 
 
 cpage_redisplay:
   printf("\nLevel %d Control Page at block %lld\n\n", type,
@@ -363,23 +344,19 @@ cpage_retry:
     rc = display_tree(&ctl_page, lblock, &changed);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmapctl_t( &ctl_page ); 
-    }
+    ujfs_swap_dmapctl_t( &ctl_page ); 
 
     if (changed && xWrite(address, sizeof(dmapctl_t),
                           (char *)&ctl_page)) {
       fputs("display_cpage: Error writing control page!\n",
             stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dmapctl_t( &ctl_page ); 
+      ujfs_swap_dmapctl_t( &ctl_page ); 
       return DMAP_EXIT;
     }
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmapctl_t( &ctl_page ); 
-    }
+    ujfs_swap_dmapctl_t( &ctl_page ); 
 
     return rc;
   }
@@ -496,22 +473,18 @@ cpage_retry:
     }
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmapctl_t( &ctl_page ); 
-    }
+    ujfs_swap_dmapctl_t( &ctl_page ); 
 
     if (xWrite(address, sizeof(dmapctl_t), (char *)&ctl_page)) {
       fputs("display_cpage: Error writing control page!\n",
             stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dmapctl_t( &ctl_page ); 
+      ujfs_swap_dmapctl_t( &ctl_page ); 
       return DMAP_EXIT;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmapctl_t( &ctl_page ); 
-    }
+    ujfs_swap_dmapctl_t( &ctl_page ); 
 
     goto cpage_redisplay;
   }
@@ -554,9 +527,7 @@ int32_t display_leaf( dinode_t  *bmap_inode,
   }
 
   /* swap if on big endian machine */
-  if (type_jfs & JFS_SWAP_BYTES) {
-    ujfs_swap_dmap_t( &d_map ); 
-  }
+  ujfs_swap_dmap_t( &d_map ); 
 
 leaf_redisplay:
   printf("\nDmap Page at block %lld\n\n", (long long)(address >> l2bsize));
@@ -584,23 +555,19 @@ leaf_retry:
   if ((token == 0) || (token[0] == 's')) {
     rc = display_tree((dmapctl_t *)&d_map.tree, lblock, &changed);
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmap_t( &d_map ); 
-    }
+    ujfs_swap_dmap_t( &d_map ); 
 
     if (changed &&
         xWrite(address, sizeof(dmap_t), (char *)&d_map)) {
       fputs("display_leaf: Error writing dmap page!\n",
             stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dmap_t( &d_map ); 
+      ujfs_swap_dmap_t( &d_map ); 
       return DMAP_EXIT;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmap_t( &d_map ); 
-    }
+    ujfs_swap_dmap_t( &d_map ); 
 
     return rc;
   }
@@ -651,23 +618,19 @@ leaf_retry:
       rc = display_map(d_map.wmap, LPERDMAP);
 
     /* swap if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmap_t( &d_map ); 
-    }
+    ujfs_swap_dmap_t( &d_map ); 
 
     if ((rc & XPEEK_CHANGED) &&
         xWrite(address, sizeof(dmap_t), (char *)&d_map)) {
       fputs("display_leaf: Error writing dmap page!\n",
             stderr);
       /* swap back if on big endian machine */
-      if (type_jfs & JFS_SWAP_BYTES) ujfs_swap_dmap_t( &d_map ); 
+      ujfs_swap_dmap_t( &d_map ); 
       return DMAP_EXIT;
     }
 
     /* swap back if on big endian machine */
-    if (type_jfs & JFS_SWAP_BYTES) {
-      ujfs_swap_dmap_t( &d_map ); 
-    }
+    ujfs_swap_dmap_t( &d_map ); 
 
     if (rc & XPEEK_REDISPLAY)
       goto leaf_redisplay;
